/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface AclBindingRuleConfig extends cdktf.TerraformMetaArguments {
    /**
    * The name of the ACL auth method this rule apply.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/acl_binding_rule#auth_method AclBindingRule#auth_method}
    */
    readonly authMethod: string;
    /**
    * The name to bind to a token at login-time.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/acl_binding_rule#bind_name AclBindingRule#bind_name}
    */
    readonly bindName: string;
    /**
    * Specifies the way the binding rule affects a token created at login.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/acl_binding_rule#bind_type AclBindingRule#bind_type}
    */
    readonly bindType: string;
    /**
    * A free form human readable description of the binding rule.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/acl_binding_rule#description AclBindingRule#description}
    */
    readonly description?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/acl_binding_rule#id AclBindingRule#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The namespace to create the binding rule within.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/acl_binding_rule#namespace AclBindingRule#namespace}
    */
    readonly namespace?: string;
    /**
    * The partition the ACL binding rule is associated with.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/acl_binding_rule#partition AclBindingRule#partition}
    */
    readonly partition?: string;
    /**
    * The expression used to match this rule against valid identities returned from an auth method validation.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/acl_binding_rule#selector AclBindingRule#selector}
    */
    readonly selector?: string;
    /**
    * bind_vars block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/acl_binding_rule#bind_vars AclBindingRule#bind_vars}
    */
    readonly bindVars?: AclBindingRuleBindVars;
}
export interface AclBindingRuleBindVars {
    /**
    * The name of node, workload identity or service.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/acl_binding_rule#name AclBindingRule#name}
    */
    readonly name?: string;
}
export declare function aclBindingRuleBindVarsToTerraform(struct?: AclBindingRuleBindVarsOutputReference | AclBindingRuleBindVars): any;
export declare function aclBindingRuleBindVarsToHclTerraform(struct?: AclBindingRuleBindVarsOutputReference | AclBindingRuleBindVars): any;
export declare class AclBindingRuleBindVarsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): AclBindingRuleBindVars | undefined;
    set internalValue(value: AclBindingRuleBindVars | undefined);
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/acl_binding_rule consul_acl_binding_rule}
*/
export declare class AclBindingRule extends cdktf.TerraformResource {
    static readonly tfResourceType = "consul_acl_binding_rule";
    /**
    * Generates CDKTF code for importing a AclBindingRule resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the AclBindingRule to import
    * @param importFromId The id of the existing AclBindingRule that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/acl_binding_rule#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the AclBindingRule to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/acl_binding_rule consul_acl_binding_rule} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options AclBindingRuleConfig
    */
    constructor(scope: Construct, id: string, config: AclBindingRuleConfig);
    private _authMethod?;
    get authMethod(): string;
    set authMethod(value: string);
    get authMethodInput(): string | undefined;
    private _bindName?;
    get bindName(): string;
    set bindName(value: string);
    get bindNameInput(): string | undefined;
    private _bindType?;
    get bindType(): string;
    set bindType(value: string);
    get bindTypeInput(): string | undefined;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _namespace?;
    get namespace(): string;
    set namespace(value: string);
    resetNamespace(): void;
    get namespaceInput(): string | undefined;
    private _partition?;
    get partition(): string;
    set partition(value: string);
    resetPartition(): void;
    get partitionInput(): string | undefined;
    private _selector?;
    get selector(): string;
    set selector(value: string);
    resetSelector(): void;
    get selectorInput(): string | undefined;
    private _bindVars;
    get bindVars(): AclBindingRuleBindVarsOutputReference;
    putBindVars(value: AclBindingRuleBindVars): void;
    resetBindVars(): void;
    get bindVarsInput(): AclBindingRuleBindVars | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
