/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface AclTokenConfig extends cdktf.TerraformMetaArguments {
    /**
    * The uuid of the token. If omitted, Consul will generate a random uuid.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/acl_token#accessor_id AclToken#accessor_id}
    */
    readonly accessorId?: string;
    /**
    * The description of the token.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/acl_token#description AclToken#description}
    */
    readonly description?: string;
    /**
    * If set this represents the point after which a token should be considered revoked and is eligible for destruction.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/acl_token#expiration_time AclToken#expiration_time}
    */
    readonly expirationTime?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/acl_token#id AclToken#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The flag to set the token local to the current datacenter.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/acl_token#local AclToken#local}
    */
    readonly local?: boolean | cdktf.IResolvable;
    /**
    * The namespace to create the token within.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/acl_token#namespace AclToken#namespace}
    */
    readonly namespace?: string;
    /**
    * The partition the ACL token is associated with.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/acl_token#partition AclToken#partition}
    */
    readonly partition?: string;
    /**
    * The list of policies attached to the token.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/acl_token#policies AclToken#policies}
    */
    readonly policies?: string[];
    /**
    * The list of roles attached to the token.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/acl_token#roles AclToken#roles}
    */
    readonly roles?: string[];
    /**
    * node_identities block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/acl_token#node_identities AclToken#node_identities}
    */
    readonly nodeIdentities?: AclTokenNodeIdentities[] | cdktf.IResolvable;
    /**
    * service_identities block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/acl_token#service_identities AclToken#service_identities}
    */
    readonly serviceIdentities?: AclTokenServiceIdentities[] | cdktf.IResolvable;
    /**
    * templated_policies block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/acl_token#templated_policies AclToken#templated_policies}
    */
    readonly templatedPolicies?: AclTokenTemplatedPolicies[] | cdktf.IResolvable;
}
export interface AclTokenNodeIdentities {
    /**
    * The datacenter of the node.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/acl_token#datacenter AclToken#datacenter}
    */
    readonly datacenter: string;
    /**
    * The name of the node.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/acl_token#node_name AclToken#node_name}
    */
    readonly nodeName: string;
}
export declare function aclTokenNodeIdentitiesToTerraform(struct?: AclTokenNodeIdentities | cdktf.IResolvable): any;
export declare function aclTokenNodeIdentitiesToHclTerraform(struct?: AclTokenNodeIdentities | cdktf.IResolvable): any;
export declare class AclTokenNodeIdentitiesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): AclTokenNodeIdentities | cdktf.IResolvable | undefined;
    set internalValue(value: AclTokenNodeIdentities | cdktf.IResolvable | undefined);
    private _datacenter?;
    get datacenter(): string;
    set datacenter(value: string);
    get datacenterInput(): string | undefined;
    private _nodeName?;
    get nodeName(): string;
    set nodeName(value: string);
    get nodeNameInput(): string | undefined;
}
export declare class AclTokenNodeIdentitiesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: AclTokenNodeIdentities[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): AclTokenNodeIdentitiesOutputReference;
}
export interface AclTokenServiceIdentities {
    /**
    * Specifies the datacenters the effective policy is valid within.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/acl_token#datacenters AclToken#datacenters}
    */
    readonly datacenters?: string[];
    /**
    * The name of the service.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/acl_token#service_name AclToken#service_name}
    */
    readonly serviceName: string;
}
export declare function aclTokenServiceIdentitiesToTerraform(struct?: AclTokenServiceIdentities | cdktf.IResolvable): any;
export declare function aclTokenServiceIdentitiesToHclTerraform(struct?: AclTokenServiceIdentities | cdktf.IResolvable): any;
export declare class AclTokenServiceIdentitiesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): AclTokenServiceIdentities | cdktf.IResolvable | undefined;
    set internalValue(value: AclTokenServiceIdentities | cdktf.IResolvable | undefined);
    private _datacenters?;
    get datacenters(): string[];
    set datacenters(value: string[]);
    resetDatacenters(): void;
    get datacentersInput(): string[] | undefined;
    private _serviceName?;
    get serviceName(): string;
    set serviceName(value: string);
    get serviceNameInput(): string | undefined;
}
export declare class AclTokenServiceIdentitiesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: AclTokenServiceIdentities[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): AclTokenServiceIdentitiesOutputReference;
}
export interface AclTokenTemplatedPoliciesTemplateVariables {
    /**
    * The name of node, workload identity or service.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/acl_token#name AclToken#name}
    */
    readonly name?: string;
}
export declare function aclTokenTemplatedPoliciesTemplateVariablesToTerraform(struct?: AclTokenTemplatedPoliciesTemplateVariablesOutputReference | AclTokenTemplatedPoliciesTemplateVariables): any;
export declare function aclTokenTemplatedPoliciesTemplateVariablesToHclTerraform(struct?: AclTokenTemplatedPoliciesTemplateVariablesOutputReference | AclTokenTemplatedPoliciesTemplateVariables): any;
export declare class AclTokenTemplatedPoliciesTemplateVariablesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): AclTokenTemplatedPoliciesTemplateVariables | undefined;
    set internalValue(value: AclTokenTemplatedPoliciesTemplateVariables | undefined);
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
}
export interface AclTokenTemplatedPolicies {
    /**
    * Specifies the datacenters the effective policy is valid within.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/acl_token#datacenters AclToken#datacenters}
    */
    readonly datacenters?: string[];
    /**
    * The name of the templated policies.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/acl_token#template_name AclToken#template_name}
    */
    readonly templateName: string;
    /**
    * template_variables block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/acl_token#template_variables AclToken#template_variables}
    */
    readonly templateVariables?: AclTokenTemplatedPoliciesTemplateVariables;
}
export declare function aclTokenTemplatedPoliciesToTerraform(struct?: AclTokenTemplatedPolicies | cdktf.IResolvable): any;
export declare function aclTokenTemplatedPoliciesToHclTerraform(struct?: AclTokenTemplatedPolicies | cdktf.IResolvable): any;
export declare class AclTokenTemplatedPoliciesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): AclTokenTemplatedPolicies | cdktf.IResolvable | undefined;
    set internalValue(value: AclTokenTemplatedPolicies | cdktf.IResolvable | undefined);
    private _datacenters?;
    get datacenters(): string[];
    set datacenters(value: string[]);
    resetDatacenters(): void;
    get datacentersInput(): string[] | undefined;
    private _templateName?;
    get templateName(): string;
    set templateName(value: string);
    get templateNameInput(): string | undefined;
    private _templateVariables;
    get templateVariables(): AclTokenTemplatedPoliciesTemplateVariablesOutputReference;
    putTemplateVariables(value: AclTokenTemplatedPoliciesTemplateVariables): void;
    resetTemplateVariables(): void;
    get templateVariablesInput(): AclTokenTemplatedPoliciesTemplateVariables | undefined;
}
export declare class AclTokenTemplatedPoliciesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: AclTokenTemplatedPolicies[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): AclTokenTemplatedPoliciesOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/acl_token consul_acl_token}
*/
export declare class AclToken extends cdktf.TerraformResource {
    static readonly tfResourceType = "consul_acl_token";
    /**
    * Generates CDKTF code for importing a AclToken resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the AclToken to import
    * @param importFromId The id of the existing AclToken that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/acl_token#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the AclToken to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/acl_token consul_acl_token} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options AclTokenConfig = {}
    */
    constructor(scope: Construct, id: string, config?: AclTokenConfig);
    private _accessorId?;
    get accessorId(): string;
    set accessorId(value: string);
    resetAccessorId(): void;
    get accessorIdInput(): string | undefined;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _expirationTime?;
    get expirationTime(): string;
    set expirationTime(value: string);
    resetExpirationTime(): void;
    get expirationTimeInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _local?;
    get local(): boolean | cdktf.IResolvable;
    set local(value: boolean | cdktf.IResolvable);
    resetLocal(): void;
    get localInput(): boolean | cdktf.IResolvable | undefined;
    private _namespace?;
    get namespace(): string;
    set namespace(value: string);
    resetNamespace(): void;
    get namespaceInput(): string | undefined;
    private _partition?;
    get partition(): string;
    set partition(value: string);
    resetPartition(): void;
    get partitionInput(): string | undefined;
    private _policies?;
    get policies(): string[];
    set policies(value: string[]);
    resetPolicies(): void;
    get policiesInput(): string[] | undefined;
    private _roles?;
    get roles(): string[];
    set roles(value: string[]);
    resetRoles(): void;
    get rolesInput(): string[] | undefined;
    private _nodeIdentities;
    get nodeIdentities(): AclTokenNodeIdentitiesList;
    putNodeIdentities(value: AclTokenNodeIdentities[] | cdktf.IResolvable): void;
    resetNodeIdentities(): void;
    get nodeIdentitiesInput(): cdktf.IResolvable | AclTokenNodeIdentities[] | undefined;
    private _serviceIdentities;
    get serviceIdentities(): AclTokenServiceIdentitiesList;
    putServiceIdentities(value: AclTokenServiceIdentities[] | cdktf.IResolvable): void;
    resetServiceIdentities(): void;
    get serviceIdentitiesInput(): cdktf.IResolvable | AclTokenServiceIdentities[] | undefined;
    private _templatedPolicies;
    get templatedPolicies(): AclTokenTemplatedPoliciesList;
    putTemplatedPolicies(value: AclTokenTemplatedPolicies[] | cdktf.IResolvable): void;
    resetTemplatedPolicies(): void;
    get templatedPoliciesInput(): cdktf.IResolvable | AclTokenTemplatedPolicies[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
