/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface ConfigEntryServiceDefaultsConfig extends cdktf.TerraformMetaArguments {
    /**
    * Specifies the strategy for allocating inbound connections to the service across Envoy proxy threads.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_defaults#balance_inbound_connections ConfigEntryServiceDefaults#balance_inbound_connections}
    */
    readonly balanceInboundConnections?: string;
    /**
    * Specifies the TLS server name indication (SNI) when federating with an external system.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_defaults#external_sni ConfigEntryServiceDefaults#external_sni}
    */
    readonly externalSni?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_defaults#id ConfigEntryServiceDefaults#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Specifies the number of milliseconds allowed for establishing connections to the local application instance before timing out.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_defaults#local_connect_timeout_ms ConfigEntryServiceDefaults#local_connect_timeout_ms}
    */
    readonly localConnectTimeoutMs?: number;
    /**
    * Specifies the timeout for HTTP requests to the local application instance.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_defaults#local_request_timeout_ms ConfigEntryServiceDefaults#local_request_timeout_ms}
    */
    readonly localRequestTimeoutMs?: number;
    /**
    * Specifies the maximum number of concurrent inbound connections to each service instance.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_defaults#max_inbound_connections ConfigEntryServiceDefaults#max_inbound_connections}
    */
    readonly maxInboundConnections?: number;
    /**
    * Specifies a set of custom key-value pairs to add to the Consul KV store.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_defaults#meta ConfigEntryServiceDefaults#meta}
    */
    readonly meta?: {
        [key: string]: string;
    };
    /**
    * Specifies a mode for how the service directs inbound and outbound traffic.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_defaults#mode ConfigEntryServiceDefaults#mode}
    */
    readonly mode?: string;
    /**
    * Controls whether mutual TLS is required for incoming connections to this service. This setting is only supported for services with transparent proxy enabled.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_defaults#mutual_tls_mode ConfigEntryServiceDefaults#mutual_tls_mode}
    */
    readonly mutualTlsMode?: string;
    /**
    * Specifies the name of the service you are setting the defaults for.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_defaults#name ConfigEntryServiceDefaults#name}
    */
    readonly name: string;
    /**
    * Specifies the Consul namespace that the configuration entry applies to.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_defaults#namespace ConfigEntryServiceDefaults#namespace}
    */
    readonly namespace?: string;
    /**
    * Specifies the name of the name of the Consul admin partition that the configuration entry applies to. Refer to Admin Partitions for additional information.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_defaults#partition ConfigEntryServiceDefaults#partition}
    */
    readonly partition?: string;
    /**
    * Specifies the default protocol for the service.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_defaults#protocol ConfigEntryServiceDefaults#protocol}
    */
    readonly protocol: string;
    /**
    * destination block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_defaults#destination ConfigEntryServiceDefaults#destination}
    */
    readonly destination?: ConfigEntryServiceDefaultsDestination[] | cdktf.IResolvable;
    /**
    * envoy_extensions block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_defaults#envoy_extensions ConfigEntryServiceDefaults#envoy_extensions}
    */
    readonly envoyExtensions?: ConfigEntryServiceDefaultsEnvoyExtensions[] | cdktf.IResolvable;
    /**
    * expose block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_defaults#expose ConfigEntryServiceDefaults#expose}
    */
    readonly expose: ConfigEntryServiceDefaultsExpose[] | cdktf.IResolvable;
    /**
    * mesh_gateway block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_defaults#mesh_gateway ConfigEntryServiceDefaults#mesh_gateway}
    */
    readonly meshGateway?: ConfigEntryServiceDefaultsMeshGateway[] | cdktf.IResolvable;
    /**
    * transparent_proxy block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_defaults#transparent_proxy ConfigEntryServiceDefaults#transparent_proxy}
    */
    readonly transparentProxy?: ConfigEntryServiceDefaultsTransparentProxy[] | cdktf.IResolvable;
    /**
    * upstream_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_defaults#upstream_config ConfigEntryServiceDefaults#upstream_config}
    */
    readonly upstreamConfig?: ConfigEntryServiceDefaultsUpstreamConfig[] | cdktf.IResolvable;
}
export interface ConfigEntryServiceDefaultsDestination {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_defaults#addresses ConfigEntryServiceDefaults#addresses}
    */
    readonly addresses: string[];
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_defaults#port ConfigEntryServiceDefaults#port}
    */
    readonly port: number;
}
export declare function configEntryServiceDefaultsDestinationToTerraform(struct?: ConfigEntryServiceDefaultsDestination | cdktf.IResolvable): any;
export declare function configEntryServiceDefaultsDestinationToHclTerraform(struct?: ConfigEntryServiceDefaultsDestination | cdktf.IResolvable): any;
export declare class ConfigEntryServiceDefaultsDestinationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ConfigEntryServiceDefaultsDestination | cdktf.IResolvable | undefined;
    set internalValue(value: ConfigEntryServiceDefaultsDestination | cdktf.IResolvable | undefined);
    private _addresses?;
    get addresses(): string[];
    set addresses(value: string[]);
    get addressesInput(): string[] | undefined;
    private _port?;
    get port(): number;
    set port(value: number);
    get portInput(): number | undefined;
}
export declare class ConfigEntryServiceDefaultsDestinationList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ConfigEntryServiceDefaultsDestination[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ConfigEntryServiceDefaultsDestinationOutputReference;
}
export interface ConfigEntryServiceDefaultsEnvoyExtensions {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_defaults#arguments ConfigEntryServiceDefaults#arguments}
    */
    readonly arguments?: {
        [key: string]: string;
    };
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_defaults#consul_version ConfigEntryServiceDefaults#consul_version}
    */
    readonly consulVersion?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_defaults#envoy_version ConfigEntryServiceDefaults#envoy_version}
    */
    readonly envoyVersion?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_defaults#name ConfigEntryServiceDefaults#name}
    */
    readonly name?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_defaults#required ConfigEntryServiceDefaults#required}
    */
    readonly required?: boolean | cdktf.IResolvable;
}
export declare function configEntryServiceDefaultsEnvoyExtensionsToTerraform(struct?: ConfigEntryServiceDefaultsEnvoyExtensions | cdktf.IResolvable): any;
export declare function configEntryServiceDefaultsEnvoyExtensionsToHclTerraform(struct?: ConfigEntryServiceDefaultsEnvoyExtensions | cdktf.IResolvable): any;
export declare class ConfigEntryServiceDefaultsEnvoyExtensionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ConfigEntryServiceDefaultsEnvoyExtensions | cdktf.IResolvable | undefined;
    set internalValue(value: ConfigEntryServiceDefaultsEnvoyExtensions | cdktf.IResolvable | undefined);
    private _arguments?;
    get arguments(): {
        [key: string]: string;
    };
    set arguments(value: {
        [key: string]: string;
    });
    resetArguments(): void;
    get argumentsInput(): {
        [key: string]: string;
    } | undefined;
    private _consulVersion?;
    get consulVersion(): string;
    set consulVersion(value: string);
    resetConsulVersion(): void;
    get consulVersionInput(): string | undefined;
    private _envoyVersion?;
    get envoyVersion(): string;
    set envoyVersion(value: string);
    resetEnvoyVersion(): void;
    get envoyVersionInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
    private _required?;
    get required(): boolean | cdktf.IResolvable;
    set required(value: boolean | cdktf.IResolvable);
    resetRequired(): void;
    get requiredInput(): boolean | cdktf.IResolvable | undefined;
}
export declare class ConfigEntryServiceDefaultsEnvoyExtensionsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ConfigEntryServiceDefaultsEnvoyExtensions[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ConfigEntryServiceDefaultsEnvoyExtensionsOutputReference;
}
export interface ConfigEntryServiceDefaultsExposePaths {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_defaults#listener_port ConfigEntryServiceDefaults#listener_port}
    */
    readonly listenerPort?: number;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_defaults#local_path_port ConfigEntryServiceDefaults#local_path_port}
    */
    readonly localPathPort?: number;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_defaults#path ConfigEntryServiceDefaults#path}
    */
    readonly path?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_defaults#protocol ConfigEntryServiceDefaults#protocol}
    */
    readonly protocol?: string;
}
export declare function configEntryServiceDefaultsExposePathsToTerraform(struct?: ConfigEntryServiceDefaultsExposePaths | cdktf.IResolvable): any;
export declare function configEntryServiceDefaultsExposePathsToHclTerraform(struct?: ConfigEntryServiceDefaultsExposePaths | cdktf.IResolvable): any;
export declare class ConfigEntryServiceDefaultsExposePathsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ConfigEntryServiceDefaultsExposePaths | cdktf.IResolvable | undefined;
    set internalValue(value: ConfigEntryServiceDefaultsExposePaths | cdktf.IResolvable | undefined);
    private _listenerPort?;
    get listenerPort(): number;
    set listenerPort(value: number);
    resetListenerPort(): void;
    get listenerPortInput(): number | undefined;
    private _localPathPort?;
    get localPathPort(): number;
    set localPathPort(value: number);
    resetLocalPathPort(): void;
    get localPathPortInput(): number | undefined;
    private _path?;
    get path(): string;
    set path(value: string);
    resetPath(): void;
    get pathInput(): string | undefined;
    private _protocol?;
    get protocol(): string;
    set protocol(value: string);
    resetProtocol(): void;
    get protocolInput(): string | undefined;
}
export declare class ConfigEntryServiceDefaultsExposePathsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ConfigEntryServiceDefaultsExposePaths[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ConfigEntryServiceDefaultsExposePathsOutputReference;
}
export interface ConfigEntryServiceDefaultsExpose {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_defaults#checks ConfigEntryServiceDefaults#checks}
    */
    readonly checks?: boolean | cdktf.IResolvable;
    /**
    * paths block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_defaults#paths ConfigEntryServiceDefaults#paths}
    */
    readonly paths?: ConfigEntryServiceDefaultsExposePaths[] | cdktf.IResolvable;
}
export declare function configEntryServiceDefaultsExposeToTerraform(struct?: ConfigEntryServiceDefaultsExpose | cdktf.IResolvable): any;
export declare function configEntryServiceDefaultsExposeToHclTerraform(struct?: ConfigEntryServiceDefaultsExpose | cdktf.IResolvable): any;
export declare class ConfigEntryServiceDefaultsExposeOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ConfigEntryServiceDefaultsExpose | cdktf.IResolvable | undefined;
    set internalValue(value: ConfigEntryServiceDefaultsExpose | cdktf.IResolvable | undefined);
    private _checks?;
    get checks(): boolean | cdktf.IResolvable;
    set checks(value: boolean | cdktf.IResolvable);
    resetChecks(): void;
    get checksInput(): boolean | cdktf.IResolvable | undefined;
    private _paths;
    get paths(): ConfigEntryServiceDefaultsExposePathsList;
    putPaths(value: ConfigEntryServiceDefaultsExposePaths[] | cdktf.IResolvable): void;
    resetPaths(): void;
    get pathsInput(): cdktf.IResolvable | ConfigEntryServiceDefaultsExposePaths[] | undefined;
}
export declare class ConfigEntryServiceDefaultsExposeList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ConfigEntryServiceDefaultsExpose[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ConfigEntryServiceDefaultsExposeOutputReference;
}
export interface ConfigEntryServiceDefaultsMeshGateway {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_defaults#mode ConfigEntryServiceDefaults#mode}
    */
    readonly mode: string;
}
export declare function configEntryServiceDefaultsMeshGatewayToTerraform(struct?: ConfigEntryServiceDefaultsMeshGateway | cdktf.IResolvable): any;
export declare function configEntryServiceDefaultsMeshGatewayToHclTerraform(struct?: ConfigEntryServiceDefaultsMeshGateway | cdktf.IResolvable): any;
export declare class ConfigEntryServiceDefaultsMeshGatewayOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ConfigEntryServiceDefaultsMeshGateway | cdktf.IResolvable | undefined;
    set internalValue(value: ConfigEntryServiceDefaultsMeshGateway | cdktf.IResolvable | undefined);
    private _mode?;
    get mode(): string;
    set mode(value: string);
    get modeInput(): string | undefined;
}
export declare class ConfigEntryServiceDefaultsMeshGatewayList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ConfigEntryServiceDefaultsMeshGateway[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ConfigEntryServiceDefaultsMeshGatewayOutputReference;
}
export interface ConfigEntryServiceDefaultsTransparentProxy {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_defaults#dialed_directly ConfigEntryServiceDefaults#dialed_directly}
    */
    readonly dialedDirectly: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_defaults#outbound_listener_port ConfigEntryServiceDefaults#outbound_listener_port}
    */
    readonly outboundListenerPort: number;
}
export declare function configEntryServiceDefaultsTransparentProxyToTerraform(struct?: ConfigEntryServiceDefaultsTransparentProxy | cdktf.IResolvable): any;
export declare function configEntryServiceDefaultsTransparentProxyToHclTerraform(struct?: ConfigEntryServiceDefaultsTransparentProxy | cdktf.IResolvable): any;
export declare class ConfigEntryServiceDefaultsTransparentProxyOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ConfigEntryServiceDefaultsTransparentProxy | cdktf.IResolvable | undefined;
    set internalValue(value: ConfigEntryServiceDefaultsTransparentProxy | cdktf.IResolvable | undefined);
    private _dialedDirectly?;
    get dialedDirectly(): boolean | cdktf.IResolvable;
    set dialedDirectly(value: boolean | cdktf.IResolvable);
    get dialedDirectlyInput(): boolean | cdktf.IResolvable | undefined;
    private _outboundListenerPort?;
    get outboundListenerPort(): number;
    set outboundListenerPort(value: number);
    get outboundListenerPortInput(): number | undefined;
}
export declare class ConfigEntryServiceDefaultsTransparentProxyList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ConfigEntryServiceDefaultsTransparentProxy[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ConfigEntryServiceDefaultsTransparentProxyOutputReference;
}
export interface ConfigEntryServiceDefaultsUpstreamConfigDefaultsLimits {
    /**
    * Specifies the maximum number of concurrent requests.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_defaults#max_concurrent_requests ConfigEntryServiceDefaults#max_concurrent_requests}
    */
    readonly maxConcurrentRequests?: number;
    /**
    * Specifies the maximum number of connections a service instance can establish against the upstream.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_defaults#max_connections ConfigEntryServiceDefaults#max_connections}
    */
    readonly maxConnections?: number;
    /**
    * Specifies the maximum number of requests that are queued while waiting for a connection to establish.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_defaults#max_pending_requests ConfigEntryServiceDefaults#max_pending_requests}
    */
    readonly maxPendingRequests?: number;
}
export declare function configEntryServiceDefaultsUpstreamConfigDefaultsLimitsToTerraform(struct?: ConfigEntryServiceDefaultsUpstreamConfigDefaultsLimits | cdktf.IResolvable): any;
export declare function configEntryServiceDefaultsUpstreamConfigDefaultsLimitsToHclTerraform(struct?: ConfigEntryServiceDefaultsUpstreamConfigDefaultsLimits | cdktf.IResolvable): any;
export declare class ConfigEntryServiceDefaultsUpstreamConfigDefaultsLimitsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ConfigEntryServiceDefaultsUpstreamConfigDefaultsLimits | cdktf.IResolvable | undefined;
    set internalValue(value: ConfigEntryServiceDefaultsUpstreamConfigDefaultsLimits | cdktf.IResolvable | undefined);
    private _maxConcurrentRequests?;
    get maxConcurrentRequests(): number;
    set maxConcurrentRequests(value: number);
    resetMaxConcurrentRequests(): void;
    get maxConcurrentRequestsInput(): number | undefined;
    private _maxConnections?;
    get maxConnections(): number;
    set maxConnections(value: number);
    resetMaxConnections(): void;
    get maxConnectionsInput(): number | undefined;
    private _maxPendingRequests?;
    get maxPendingRequests(): number;
    set maxPendingRequests(value: number);
    resetMaxPendingRequests(): void;
    get maxPendingRequestsInput(): number | undefined;
}
export declare class ConfigEntryServiceDefaultsUpstreamConfigDefaultsLimitsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ConfigEntryServiceDefaultsUpstreamConfigDefaultsLimits[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ConfigEntryServiceDefaultsUpstreamConfigDefaultsLimitsOutputReference;
}
export interface ConfigEntryServiceDefaultsUpstreamConfigDefaultsMeshGateway {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_defaults#mode ConfigEntryServiceDefaults#mode}
    */
    readonly mode?: string;
}
export declare function configEntryServiceDefaultsUpstreamConfigDefaultsMeshGatewayToTerraform(struct?: ConfigEntryServiceDefaultsUpstreamConfigDefaultsMeshGateway | cdktf.IResolvable): any;
export declare function configEntryServiceDefaultsUpstreamConfigDefaultsMeshGatewayToHclTerraform(struct?: ConfigEntryServiceDefaultsUpstreamConfigDefaultsMeshGateway | cdktf.IResolvable): any;
export declare class ConfigEntryServiceDefaultsUpstreamConfigDefaultsMeshGatewayOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ConfigEntryServiceDefaultsUpstreamConfigDefaultsMeshGateway | cdktf.IResolvable | undefined;
    set internalValue(value: ConfigEntryServiceDefaultsUpstreamConfigDefaultsMeshGateway | cdktf.IResolvable | undefined);
    private _mode?;
    get mode(): string;
    set mode(value: string);
    resetMode(): void;
    get modeInput(): string | undefined;
}
export declare class ConfigEntryServiceDefaultsUpstreamConfigDefaultsMeshGatewayList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ConfigEntryServiceDefaultsUpstreamConfigDefaultsMeshGateway[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ConfigEntryServiceDefaultsUpstreamConfigDefaultsMeshGatewayOutputReference;
}
export interface ConfigEntryServiceDefaultsUpstreamConfigDefaultsPassiveHealthCheck {
    /**
    * Specifies the minimum amount of time that an ejected host must remain outside the cluster before rejoining.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_defaults#base_ejection_time ConfigEntryServiceDefaults#base_ejection_time}
    */
    readonly baseEjectionTime?: string;
    /**
    * Specifies a percentage that indicates how many times out of 100 that Consul ejects the host when it detects an outlier status.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_defaults#enforcing_consecutive_5xx ConfigEntryServiceDefaults#enforcing_consecutive_5xx}
    */
    readonly enforcingConsecutive5Xx?: number;
    /**
    * Specifies the time between checks.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_defaults#interval ConfigEntryServiceDefaults#interval}
    */
    readonly interval?: string;
    /**
    * Specifies the maximum percentage of an upstream cluster that Consul ejects when the proxy reports an outlier.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_defaults#max_ejection_percent ConfigEntryServiceDefaults#max_ejection_percent}
    */
    readonly maxEjectionPercent?: number;
    /**
    * Specifies the number of consecutive failures allowed per check interval. If exceeded, Consul removes the host from the load balancer.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_defaults#max_failures ConfigEntryServiceDefaults#max_failures}
    */
    readonly maxFailures?: number;
}
export declare function configEntryServiceDefaultsUpstreamConfigDefaultsPassiveHealthCheckToTerraform(struct?: ConfigEntryServiceDefaultsUpstreamConfigDefaultsPassiveHealthCheck | cdktf.IResolvable): any;
export declare function configEntryServiceDefaultsUpstreamConfigDefaultsPassiveHealthCheckToHclTerraform(struct?: ConfigEntryServiceDefaultsUpstreamConfigDefaultsPassiveHealthCheck | cdktf.IResolvable): any;
export declare class ConfigEntryServiceDefaultsUpstreamConfigDefaultsPassiveHealthCheckOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ConfigEntryServiceDefaultsUpstreamConfigDefaultsPassiveHealthCheck | cdktf.IResolvable | undefined;
    set internalValue(value: ConfigEntryServiceDefaultsUpstreamConfigDefaultsPassiveHealthCheck | cdktf.IResolvable | undefined);
    private _baseEjectionTime?;
    get baseEjectionTime(): string;
    set baseEjectionTime(value: string);
    resetBaseEjectionTime(): void;
    get baseEjectionTimeInput(): string | undefined;
    private _enforcingConsecutive5Xx?;
    get enforcingConsecutive5Xx(): number;
    set enforcingConsecutive5Xx(value: number);
    resetEnforcingConsecutive5Xx(): void;
    get enforcingConsecutive5XxInput(): number | undefined;
    private _interval?;
    get interval(): string;
    set interval(value: string);
    resetInterval(): void;
    get intervalInput(): string | undefined;
    private _maxEjectionPercent?;
    get maxEjectionPercent(): number;
    set maxEjectionPercent(value: number);
    resetMaxEjectionPercent(): void;
    get maxEjectionPercentInput(): number | undefined;
    private _maxFailures?;
    get maxFailures(): number;
    set maxFailures(value: number);
    resetMaxFailures(): void;
    get maxFailuresInput(): number | undefined;
}
export declare class ConfigEntryServiceDefaultsUpstreamConfigDefaultsPassiveHealthCheckList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ConfigEntryServiceDefaultsUpstreamConfigDefaultsPassiveHealthCheck[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ConfigEntryServiceDefaultsUpstreamConfigDefaultsPassiveHealthCheckOutputReference;
}
export interface ConfigEntryServiceDefaultsUpstreamConfigDefaults {
    /**
    * Sets the strategy for allocating outbound connections from upstreams across Envoy proxy threads.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_defaults#balance_outbound_connections ConfigEntryServiceDefaults#balance_outbound_connections}
    */
    readonly balanceOutboundConnections?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_defaults#connect_timeout_ms ConfigEntryServiceDefaults#connect_timeout_ms}
    */
    readonly connectTimeoutMs?: number;
    /**
    * Specifies the default protocol for the service.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_defaults#protocol ConfigEntryServiceDefaults#protocol}
    */
    readonly protocol?: string;
    /**
    * limits block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_defaults#limits ConfigEntryServiceDefaults#limits}
    */
    readonly limits?: ConfigEntryServiceDefaultsUpstreamConfigDefaultsLimits[] | cdktf.IResolvable;
    /**
    * mesh_gateway block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_defaults#mesh_gateway ConfigEntryServiceDefaults#mesh_gateway}
    */
    readonly meshGateway?: ConfigEntryServiceDefaultsUpstreamConfigDefaultsMeshGateway[] | cdktf.IResolvable;
    /**
    * passive_health_check block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_defaults#passive_health_check ConfigEntryServiceDefaults#passive_health_check}
    */
    readonly passiveHealthCheck?: ConfigEntryServiceDefaultsUpstreamConfigDefaultsPassiveHealthCheck[] | cdktf.IResolvable;
}
export declare function configEntryServiceDefaultsUpstreamConfigDefaultsToTerraform(struct?: ConfigEntryServiceDefaultsUpstreamConfigDefaults | cdktf.IResolvable): any;
export declare function configEntryServiceDefaultsUpstreamConfigDefaultsToHclTerraform(struct?: ConfigEntryServiceDefaultsUpstreamConfigDefaults | cdktf.IResolvable): any;
export declare class ConfigEntryServiceDefaultsUpstreamConfigDefaultsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ConfigEntryServiceDefaultsUpstreamConfigDefaults | cdktf.IResolvable | undefined;
    set internalValue(value: ConfigEntryServiceDefaultsUpstreamConfigDefaults | cdktf.IResolvable | undefined);
    private _balanceOutboundConnections?;
    get balanceOutboundConnections(): string;
    set balanceOutboundConnections(value: string);
    resetBalanceOutboundConnections(): void;
    get balanceOutboundConnectionsInput(): string | undefined;
    private _connectTimeoutMs?;
    get connectTimeoutMs(): number;
    set connectTimeoutMs(value: number);
    resetConnectTimeoutMs(): void;
    get connectTimeoutMsInput(): number | undefined;
    private _protocol?;
    get protocol(): string;
    set protocol(value: string);
    resetProtocol(): void;
    get protocolInput(): string | undefined;
    private _limits;
    get limits(): ConfigEntryServiceDefaultsUpstreamConfigDefaultsLimitsList;
    putLimits(value: ConfigEntryServiceDefaultsUpstreamConfigDefaultsLimits[] | cdktf.IResolvable): void;
    resetLimits(): void;
    get limitsInput(): cdktf.IResolvable | ConfigEntryServiceDefaultsUpstreamConfigDefaultsLimits[] | undefined;
    private _meshGateway;
    get meshGateway(): ConfigEntryServiceDefaultsUpstreamConfigDefaultsMeshGatewayList;
    putMeshGateway(value: ConfigEntryServiceDefaultsUpstreamConfigDefaultsMeshGateway[] | cdktf.IResolvable): void;
    resetMeshGateway(): void;
    get meshGatewayInput(): cdktf.IResolvable | ConfigEntryServiceDefaultsUpstreamConfigDefaultsMeshGateway[] | undefined;
    private _passiveHealthCheck;
    get passiveHealthCheck(): ConfigEntryServiceDefaultsUpstreamConfigDefaultsPassiveHealthCheckList;
    putPassiveHealthCheck(value: ConfigEntryServiceDefaultsUpstreamConfigDefaultsPassiveHealthCheck[] | cdktf.IResolvable): void;
    resetPassiveHealthCheck(): void;
    get passiveHealthCheckInput(): cdktf.IResolvable | ConfigEntryServiceDefaultsUpstreamConfigDefaultsPassiveHealthCheck[] | undefined;
}
export declare class ConfigEntryServiceDefaultsUpstreamConfigDefaultsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ConfigEntryServiceDefaultsUpstreamConfigDefaults[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ConfigEntryServiceDefaultsUpstreamConfigDefaultsOutputReference;
}
export interface ConfigEntryServiceDefaultsUpstreamConfigOverridesLimits {
    /**
    * Specifies the maximum number of concurrent requests.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_defaults#max_concurrent_requests ConfigEntryServiceDefaults#max_concurrent_requests}
    */
    readonly maxConcurrentRequests?: number;
    /**
    * Specifies the maximum number of connections a service instance can establish against the upstream.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_defaults#max_connections ConfigEntryServiceDefaults#max_connections}
    */
    readonly maxConnections?: number;
    /**
    * Specifies the maximum number of requests that are queued while waiting for a connection to establish.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_defaults#max_pending_requests ConfigEntryServiceDefaults#max_pending_requests}
    */
    readonly maxPendingRequests?: number;
}
export declare function configEntryServiceDefaultsUpstreamConfigOverridesLimitsToTerraform(struct?: ConfigEntryServiceDefaultsUpstreamConfigOverridesLimits | cdktf.IResolvable): any;
export declare function configEntryServiceDefaultsUpstreamConfigOverridesLimitsToHclTerraform(struct?: ConfigEntryServiceDefaultsUpstreamConfigOverridesLimits | cdktf.IResolvable): any;
export declare class ConfigEntryServiceDefaultsUpstreamConfigOverridesLimitsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ConfigEntryServiceDefaultsUpstreamConfigOverridesLimits | cdktf.IResolvable | undefined;
    set internalValue(value: ConfigEntryServiceDefaultsUpstreamConfigOverridesLimits | cdktf.IResolvable | undefined);
    private _maxConcurrentRequests?;
    get maxConcurrentRequests(): number;
    set maxConcurrentRequests(value: number);
    resetMaxConcurrentRequests(): void;
    get maxConcurrentRequestsInput(): number | undefined;
    private _maxConnections?;
    get maxConnections(): number;
    set maxConnections(value: number);
    resetMaxConnections(): void;
    get maxConnectionsInput(): number | undefined;
    private _maxPendingRequests?;
    get maxPendingRequests(): number;
    set maxPendingRequests(value: number);
    resetMaxPendingRequests(): void;
    get maxPendingRequestsInput(): number | undefined;
}
export declare class ConfigEntryServiceDefaultsUpstreamConfigOverridesLimitsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ConfigEntryServiceDefaultsUpstreamConfigOverridesLimits[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ConfigEntryServiceDefaultsUpstreamConfigOverridesLimitsOutputReference;
}
export interface ConfigEntryServiceDefaultsUpstreamConfigOverridesMeshGateway {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_defaults#mode ConfigEntryServiceDefaults#mode}
    */
    readonly mode?: string;
}
export declare function configEntryServiceDefaultsUpstreamConfigOverridesMeshGatewayToTerraform(struct?: ConfigEntryServiceDefaultsUpstreamConfigOverridesMeshGateway | cdktf.IResolvable): any;
export declare function configEntryServiceDefaultsUpstreamConfigOverridesMeshGatewayToHclTerraform(struct?: ConfigEntryServiceDefaultsUpstreamConfigOverridesMeshGateway | cdktf.IResolvable): any;
export declare class ConfigEntryServiceDefaultsUpstreamConfigOverridesMeshGatewayOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ConfigEntryServiceDefaultsUpstreamConfigOverridesMeshGateway | cdktf.IResolvable | undefined;
    set internalValue(value: ConfigEntryServiceDefaultsUpstreamConfigOverridesMeshGateway | cdktf.IResolvable | undefined);
    private _mode?;
    get mode(): string;
    set mode(value: string);
    resetMode(): void;
    get modeInput(): string | undefined;
}
export declare class ConfigEntryServiceDefaultsUpstreamConfigOverridesMeshGatewayList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ConfigEntryServiceDefaultsUpstreamConfigOverridesMeshGateway[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ConfigEntryServiceDefaultsUpstreamConfigOverridesMeshGatewayOutputReference;
}
export interface ConfigEntryServiceDefaultsUpstreamConfigOverridesPassiveHealthCheck {
    /**
    * Specifies the minimum amount of time that an ejected host must remain outside the cluster before rejoining.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_defaults#base_ejection_time ConfigEntryServiceDefaults#base_ejection_time}
    */
    readonly baseEjectionTime?: string;
    /**
    * Specifies a percentage that indicates how many times out of 100 that Consul ejects the host when it detects an outlier status.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_defaults#enforcing_consecutive_5xx ConfigEntryServiceDefaults#enforcing_consecutive_5xx}
    */
    readonly enforcingConsecutive5Xx?: number;
    /**
    * Specifies the time between checks.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_defaults#interval ConfigEntryServiceDefaults#interval}
    */
    readonly interval?: string;
    /**
    * Specifies the maximum percentage of an upstream cluster that Consul ejects when the proxy reports an outlier.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_defaults#max_ejection_percent ConfigEntryServiceDefaults#max_ejection_percent}
    */
    readonly maxEjectionPercent?: number;
    /**
    * Specifies the number of consecutive failures allowed per check interval. If exceeded, Consul removes the host from the load balancer.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_defaults#max_failures ConfigEntryServiceDefaults#max_failures}
    */
    readonly maxFailures?: number;
}
export declare function configEntryServiceDefaultsUpstreamConfigOverridesPassiveHealthCheckToTerraform(struct?: ConfigEntryServiceDefaultsUpstreamConfigOverridesPassiveHealthCheck | cdktf.IResolvable): any;
export declare function configEntryServiceDefaultsUpstreamConfigOverridesPassiveHealthCheckToHclTerraform(struct?: ConfigEntryServiceDefaultsUpstreamConfigOverridesPassiveHealthCheck | cdktf.IResolvable): any;
export declare class ConfigEntryServiceDefaultsUpstreamConfigOverridesPassiveHealthCheckOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ConfigEntryServiceDefaultsUpstreamConfigOverridesPassiveHealthCheck | cdktf.IResolvable | undefined;
    set internalValue(value: ConfigEntryServiceDefaultsUpstreamConfigOverridesPassiveHealthCheck | cdktf.IResolvable | undefined);
    private _baseEjectionTime?;
    get baseEjectionTime(): string;
    set baseEjectionTime(value: string);
    resetBaseEjectionTime(): void;
    get baseEjectionTimeInput(): string | undefined;
    private _enforcingConsecutive5Xx?;
    get enforcingConsecutive5Xx(): number;
    set enforcingConsecutive5Xx(value: number);
    resetEnforcingConsecutive5Xx(): void;
    get enforcingConsecutive5XxInput(): number | undefined;
    private _interval?;
    get interval(): string;
    set interval(value: string);
    resetInterval(): void;
    get intervalInput(): string | undefined;
    private _maxEjectionPercent?;
    get maxEjectionPercent(): number;
    set maxEjectionPercent(value: number);
    resetMaxEjectionPercent(): void;
    get maxEjectionPercentInput(): number | undefined;
    private _maxFailures?;
    get maxFailures(): number;
    set maxFailures(value: number);
    resetMaxFailures(): void;
    get maxFailuresInput(): number | undefined;
}
export declare class ConfigEntryServiceDefaultsUpstreamConfigOverridesPassiveHealthCheckList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ConfigEntryServiceDefaultsUpstreamConfigOverridesPassiveHealthCheck[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ConfigEntryServiceDefaultsUpstreamConfigOverridesPassiveHealthCheckOutputReference;
}
export interface ConfigEntryServiceDefaultsUpstreamConfigOverrides {
    /**
    * Sets the strategy for allocating outbound connections from upstreams across Envoy proxy threads.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_defaults#balance_outbound_connections ConfigEntryServiceDefaults#balance_outbound_connections}
    */
    readonly balanceOutboundConnections?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_defaults#connect_timeout_ms ConfigEntryServiceDefaults#connect_timeout_ms}
    */
    readonly connectTimeoutMs?: number;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_defaults#envoy_listener_json ConfigEntryServiceDefaults#envoy_listener_json}
    */
    readonly envoyListenerJson?: string;
    /**
    * Specifies the name of the service you are setting the defaults for.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_defaults#name ConfigEntryServiceDefaults#name}
    */
    readonly name?: string;
    /**
    * Specifies the namespace containing the upstream service that the configuration applies to.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_defaults#namespace ConfigEntryServiceDefaults#namespace}
    */
    readonly namespace?: string;
    /**
    * Specifies the name of the name of the Consul admin partition that the configuration entry applies to.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_defaults#partition ConfigEntryServiceDefaults#partition}
    */
    readonly partition?: string;
    /**
    * Specifies the peer name of the upstream service that the configuration applies to.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_defaults#peer ConfigEntryServiceDefaults#peer}
    */
    readonly peer?: string;
    /**
    * Specifies the default protocol for the service.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_defaults#protocol ConfigEntryServiceDefaults#protocol}
    */
    readonly protocol?: string;
    /**
    * limits block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_defaults#limits ConfigEntryServiceDefaults#limits}
    */
    readonly limits?: ConfigEntryServiceDefaultsUpstreamConfigOverridesLimits[] | cdktf.IResolvable;
    /**
    * mesh_gateway block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_defaults#mesh_gateway ConfigEntryServiceDefaults#mesh_gateway}
    */
    readonly meshGateway?: ConfigEntryServiceDefaultsUpstreamConfigOverridesMeshGateway[] | cdktf.IResolvable;
    /**
    * passive_health_check block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_defaults#passive_health_check ConfigEntryServiceDefaults#passive_health_check}
    */
    readonly passiveHealthCheck?: ConfigEntryServiceDefaultsUpstreamConfigOverridesPassiveHealthCheck[] | cdktf.IResolvable;
}
export declare function configEntryServiceDefaultsUpstreamConfigOverridesToTerraform(struct?: ConfigEntryServiceDefaultsUpstreamConfigOverrides | cdktf.IResolvable): any;
export declare function configEntryServiceDefaultsUpstreamConfigOverridesToHclTerraform(struct?: ConfigEntryServiceDefaultsUpstreamConfigOverrides | cdktf.IResolvable): any;
export declare class ConfigEntryServiceDefaultsUpstreamConfigOverridesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ConfigEntryServiceDefaultsUpstreamConfigOverrides | cdktf.IResolvable | undefined;
    set internalValue(value: ConfigEntryServiceDefaultsUpstreamConfigOverrides | cdktf.IResolvable | undefined);
    private _balanceOutboundConnections?;
    get balanceOutboundConnections(): string;
    set balanceOutboundConnections(value: string);
    resetBalanceOutboundConnections(): void;
    get balanceOutboundConnectionsInput(): string | undefined;
    private _connectTimeoutMs?;
    get connectTimeoutMs(): number;
    set connectTimeoutMs(value: number);
    resetConnectTimeoutMs(): void;
    get connectTimeoutMsInput(): number | undefined;
    private _envoyListenerJson?;
    get envoyListenerJson(): string;
    set envoyListenerJson(value: string);
    resetEnvoyListenerJson(): void;
    get envoyListenerJsonInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
    private _namespace?;
    get namespace(): string;
    set namespace(value: string);
    resetNamespace(): void;
    get namespaceInput(): string | undefined;
    private _partition?;
    get partition(): string;
    set partition(value: string);
    resetPartition(): void;
    get partitionInput(): string | undefined;
    private _peer?;
    get peer(): string;
    set peer(value: string);
    resetPeer(): void;
    get peerInput(): string | undefined;
    private _protocol?;
    get protocol(): string;
    set protocol(value: string);
    resetProtocol(): void;
    get protocolInput(): string | undefined;
    private _limits;
    get limits(): ConfigEntryServiceDefaultsUpstreamConfigOverridesLimitsList;
    putLimits(value: ConfigEntryServiceDefaultsUpstreamConfigOverridesLimits[] | cdktf.IResolvable): void;
    resetLimits(): void;
    get limitsInput(): cdktf.IResolvable | ConfigEntryServiceDefaultsUpstreamConfigOverridesLimits[] | undefined;
    private _meshGateway;
    get meshGateway(): ConfigEntryServiceDefaultsUpstreamConfigOverridesMeshGatewayList;
    putMeshGateway(value: ConfigEntryServiceDefaultsUpstreamConfigOverridesMeshGateway[] | cdktf.IResolvable): void;
    resetMeshGateway(): void;
    get meshGatewayInput(): cdktf.IResolvable | ConfigEntryServiceDefaultsUpstreamConfigOverridesMeshGateway[] | undefined;
    private _passiveHealthCheck;
    get passiveHealthCheck(): ConfigEntryServiceDefaultsUpstreamConfigOverridesPassiveHealthCheckList;
    putPassiveHealthCheck(value: ConfigEntryServiceDefaultsUpstreamConfigOverridesPassiveHealthCheck[] | cdktf.IResolvable): void;
    resetPassiveHealthCheck(): void;
    get passiveHealthCheckInput(): cdktf.IResolvable | ConfigEntryServiceDefaultsUpstreamConfigOverridesPassiveHealthCheck[] | undefined;
}
export declare class ConfigEntryServiceDefaultsUpstreamConfigOverridesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ConfigEntryServiceDefaultsUpstreamConfigOverrides[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ConfigEntryServiceDefaultsUpstreamConfigOverridesOutputReference;
}
export interface ConfigEntryServiceDefaultsUpstreamConfig {
    /**
    * defaults block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_defaults#defaults ConfigEntryServiceDefaults#defaults}
    */
    readonly defaults?: ConfigEntryServiceDefaultsUpstreamConfigDefaults[] | cdktf.IResolvable;
    /**
    * overrides block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_defaults#overrides ConfigEntryServiceDefaults#overrides}
    */
    readonly overrides?: ConfigEntryServiceDefaultsUpstreamConfigOverrides[] | cdktf.IResolvable;
}
export declare function configEntryServiceDefaultsUpstreamConfigToTerraform(struct?: ConfigEntryServiceDefaultsUpstreamConfig | cdktf.IResolvable): any;
export declare function configEntryServiceDefaultsUpstreamConfigToHclTerraform(struct?: ConfigEntryServiceDefaultsUpstreamConfig | cdktf.IResolvable): any;
export declare class ConfigEntryServiceDefaultsUpstreamConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ConfigEntryServiceDefaultsUpstreamConfig | cdktf.IResolvable | undefined;
    set internalValue(value: ConfigEntryServiceDefaultsUpstreamConfig | cdktf.IResolvable | undefined);
    private _defaults;
    get defaults(): ConfigEntryServiceDefaultsUpstreamConfigDefaultsList;
    putDefaults(value: ConfigEntryServiceDefaultsUpstreamConfigDefaults[] | cdktf.IResolvable): void;
    resetDefaults(): void;
    get defaultsInput(): cdktf.IResolvable | ConfigEntryServiceDefaultsUpstreamConfigDefaults[] | undefined;
    private _overrides;
    get overrides(): ConfigEntryServiceDefaultsUpstreamConfigOverridesList;
    putOverrides(value: ConfigEntryServiceDefaultsUpstreamConfigOverrides[] | cdktf.IResolvable): void;
    resetOverrides(): void;
    get overridesInput(): cdktf.IResolvable | ConfigEntryServiceDefaultsUpstreamConfigOverrides[] | undefined;
}
export declare class ConfigEntryServiceDefaultsUpstreamConfigList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ConfigEntryServiceDefaultsUpstreamConfig[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ConfigEntryServiceDefaultsUpstreamConfigOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_defaults consul_config_entry_service_defaults}
*/
export declare class ConfigEntryServiceDefaults extends cdktf.TerraformResource {
    static readonly tfResourceType = "consul_config_entry_service_defaults";
    /**
    * Generates CDKTF code for importing a ConfigEntryServiceDefaults resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the ConfigEntryServiceDefaults to import
    * @param importFromId The id of the existing ConfigEntryServiceDefaults that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_defaults#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the ConfigEntryServiceDefaults to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_defaults consul_config_entry_service_defaults} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options ConfigEntryServiceDefaultsConfig
    */
    constructor(scope: Construct, id: string, config: ConfigEntryServiceDefaultsConfig);
    private _balanceInboundConnections?;
    get balanceInboundConnections(): string;
    set balanceInboundConnections(value: string);
    resetBalanceInboundConnections(): void;
    get balanceInboundConnectionsInput(): string | undefined;
    private _externalSni?;
    get externalSni(): string;
    set externalSni(value: string);
    resetExternalSni(): void;
    get externalSniInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _localConnectTimeoutMs?;
    get localConnectTimeoutMs(): number;
    set localConnectTimeoutMs(value: number);
    resetLocalConnectTimeoutMs(): void;
    get localConnectTimeoutMsInput(): number | undefined;
    private _localRequestTimeoutMs?;
    get localRequestTimeoutMs(): number;
    set localRequestTimeoutMs(value: number);
    resetLocalRequestTimeoutMs(): void;
    get localRequestTimeoutMsInput(): number | undefined;
    private _maxInboundConnections?;
    get maxInboundConnections(): number;
    set maxInboundConnections(value: number);
    resetMaxInboundConnections(): void;
    get maxInboundConnectionsInput(): number | undefined;
    private _meta?;
    get meta(): {
        [key: string]: string;
    };
    set meta(value: {
        [key: string]: string;
    });
    resetMeta(): void;
    get metaInput(): {
        [key: string]: string;
    } | undefined;
    private _mode?;
    get mode(): string;
    set mode(value: string);
    resetMode(): void;
    get modeInput(): string | undefined;
    private _mutualTlsMode?;
    get mutualTlsMode(): string;
    set mutualTlsMode(value: string);
    resetMutualTlsMode(): void;
    get mutualTlsModeInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _namespace?;
    get namespace(): string;
    set namespace(value: string);
    resetNamespace(): void;
    get namespaceInput(): string | undefined;
    private _partition?;
    get partition(): string;
    set partition(value: string);
    resetPartition(): void;
    get partitionInput(): string | undefined;
    private _protocol?;
    get protocol(): string;
    set protocol(value: string);
    get protocolInput(): string | undefined;
    private _destination;
    get destination(): ConfigEntryServiceDefaultsDestinationList;
    putDestination(value: ConfigEntryServiceDefaultsDestination[] | cdktf.IResolvable): void;
    resetDestination(): void;
    get destinationInput(): cdktf.IResolvable | ConfigEntryServiceDefaultsDestination[] | undefined;
    private _envoyExtensions;
    get envoyExtensions(): ConfigEntryServiceDefaultsEnvoyExtensionsList;
    putEnvoyExtensions(value: ConfigEntryServiceDefaultsEnvoyExtensions[] | cdktf.IResolvable): void;
    resetEnvoyExtensions(): void;
    get envoyExtensionsInput(): cdktf.IResolvable | ConfigEntryServiceDefaultsEnvoyExtensions[] | undefined;
    private _expose;
    get expose(): ConfigEntryServiceDefaultsExposeList;
    putExpose(value: ConfigEntryServiceDefaultsExpose[] | cdktf.IResolvable): void;
    get exposeInput(): cdktf.IResolvable | ConfigEntryServiceDefaultsExpose[] | undefined;
    private _meshGateway;
    get meshGateway(): ConfigEntryServiceDefaultsMeshGatewayList;
    putMeshGateway(value: ConfigEntryServiceDefaultsMeshGateway[] | cdktf.IResolvable): void;
    resetMeshGateway(): void;
    get meshGatewayInput(): cdktf.IResolvable | ConfigEntryServiceDefaultsMeshGateway[] | undefined;
    private _transparentProxy;
    get transparentProxy(): ConfigEntryServiceDefaultsTransparentProxyList;
    putTransparentProxy(value: ConfigEntryServiceDefaultsTransparentProxy[] | cdktf.IResolvable): void;
    resetTransparentProxy(): void;
    get transparentProxyInput(): cdktf.IResolvable | ConfigEntryServiceDefaultsTransparentProxy[] | undefined;
    private _upstreamConfig;
    get upstreamConfig(): ConfigEntryServiceDefaultsUpstreamConfigList;
    putUpstreamConfig(value: ConfigEntryServiceDefaultsUpstreamConfig[] | cdktf.IResolvable): void;
    resetUpstreamConfig(): void;
    get upstreamConfigInput(): cdktf.IResolvable | ConfigEntryServiceDefaultsUpstreamConfig[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
