/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface ConfigEntryServiceIntentionsConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_intentions#id ConfigEntryServiceIntentions#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Specifies key-value pairs to add to the KV store.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_intentions#meta ConfigEntryServiceIntentions#meta}
    */
    readonly meta?: {
        [key: string]: string;
    };
    /**
    * Specifies a name of the destination service for all intentions defined in the configuration entry.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_intentions#name ConfigEntryServiceIntentions#name}
    */
    readonly name: string;
    /**
    * Specifies the namespace to apply the configuration entry.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_intentions#namespace ConfigEntryServiceIntentions#namespace}
    */
    readonly namespace?: string;
    /**
    * Specifies the admin partition to apply the configuration entry.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_intentions#partition ConfigEntryServiceIntentions#partition}
    */
    readonly partition?: string;
    /**
    * jwt block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_intentions#jwt ConfigEntryServiceIntentions#jwt}
    */
    readonly jwt?: ConfigEntryServiceIntentionsJwt[] | cdktf.IResolvable;
    /**
    * sources block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_intentions#sources ConfigEntryServiceIntentions#sources}
    */
    readonly sources?: ConfigEntryServiceIntentionsSources[] | cdktf.IResolvable;
}
export interface ConfigEntryServiceIntentionsJwtProvidersVerifyClaims {
    /**
    * Specifies the path to the claim in the JSON web token.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_intentions#path ConfigEntryServiceIntentions#path}
    */
    readonly path?: string[];
    /**
    * Specifies the value to match on when verifying the the claim designated in path.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_intentions#value ConfigEntryServiceIntentions#value}
    */
    readonly value?: string;
}
export declare function configEntryServiceIntentionsJwtProvidersVerifyClaimsToTerraform(struct?: ConfigEntryServiceIntentionsJwtProvidersVerifyClaims | cdktf.IResolvable): any;
export declare function configEntryServiceIntentionsJwtProvidersVerifyClaimsToHclTerraform(struct?: ConfigEntryServiceIntentionsJwtProvidersVerifyClaims | cdktf.IResolvable): any;
export declare class ConfigEntryServiceIntentionsJwtProvidersVerifyClaimsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ConfigEntryServiceIntentionsJwtProvidersVerifyClaims | cdktf.IResolvable | undefined;
    set internalValue(value: ConfigEntryServiceIntentionsJwtProvidersVerifyClaims | cdktf.IResolvable | undefined);
    private _path?;
    get path(): string[];
    set path(value: string[]);
    resetPath(): void;
    get pathInput(): string[] | undefined;
    private _value?;
    get value(): string;
    set value(value: string);
    resetValue(): void;
    get valueInput(): string | undefined;
}
export declare class ConfigEntryServiceIntentionsJwtProvidersVerifyClaimsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ConfigEntryServiceIntentionsJwtProvidersVerifyClaims[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ConfigEntryServiceIntentionsJwtProvidersVerifyClaimsOutputReference;
}
export interface ConfigEntryServiceIntentionsJwtProviders {
    /**
    * Specifies the name of a JWT provider defined in the Name field of the jwt-provider configuration entry.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_intentions#name ConfigEntryServiceIntentions#name}
    */
    readonly name?: string;
    /**
    * verify_claims block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_intentions#verify_claims ConfigEntryServiceIntentions#verify_claims}
    */
    readonly verifyClaims?: ConfigEntryServiceIntentionsJwtProvidersVerifyClaims[] | cdktf.IResolvable;
}
export declare function configEntryServiceIntentionsJwtProvidersToTerraform(struct?: ConfigEntryServiceIntentionsJwtProviders | cdktf.IResolvable): any;
export declare function configEntryServiceIntentionsJwtProvidersToHclTerraform(struct?: ConfigEntryServiceIntentionsJwtProviders | cdktf.IResolvable): any;
export declare class ConfigEntryServiceIntentionsJwtProvidersOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ConfigEntryServiceIntentionsJwtProviders | cdktf.IResolvable | undefined;
    set internalValue(value: ConfigEntryServiceIntentionsJwtProviders | cdktf.IResolvable | undefined);
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
    private _verifyClaims;
    get verifyClaims(): ConfigEntryServiceIntentionsJwtProvidersVerifyClaimsList;
    putVerifyClaims(value: ConfigEntryServiceIntentionsJwtProvidersVerifyClaims[] | cdktf.IResolvable): void;
    resetVerifyClaims(): void;
    get verifyClaimsInput(): cdktf.IResolvable | ConfigEntryServiceIntentionsJwtProvidersVerifyClaims[] | undefined;
}
export declare class ConfigEntryServiceIntentionsJwtProvidersList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ConfigEntryServiceIntentionsJwtProviders[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ConfigEntryServiceIntentionsJwtProvidersOutputReference;
}
export interface ConfigEntryServiceIntentionsJwt {
    /**
    * providers block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_intentions#providers ConfigEntryServiceIntentions#providers}
    */
    readonly providers?: ConfigEntryServiceIntentionsJwtProviders[] | cdktf.IResolvable;
}
export declare function configEntryServiceIntentionsJwtToTerraform(struct?: ConfigEntryServiceIntentionsJwt | cdktf.IResolvable): any;
export declare function configEntryServiceIntentionsJwtToHclTerraform(struct?: ConfigEntryServiceIntentionsJwt | cdktf.IResolvable): any;
export declare class ConfigEntryServiceIntentionsJwtOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ConfigEntryServiceIntentionsJwt | cdktf.IResolvable | undefined;
    set internalValue(value: ConfigEntryServiceIntentionsJwt | cdktf.IResolvable | undefined);
    private _providers;
    get providers(): ConfigEntryServiceIntentionsJwtProvidersList;
    putProviders(value: ConfigEntryServiceIntentionsJwtProviders[] | cdktf.IResolvable): void;
    resetProviders(): void;
    get providersInput(): cdktf.IResolvable | ConfigEntryServiceIntentionsJwtProviders[] | undefined;
}
export declare class ConfigEntryServiceIntentionsJwtList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ConfigEntryServiceIntentionsJwt[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ConfigEntryServiceIntentionsJwtOutputReference;
}
export interface ConfigEntryServiceIntentionsSourcesPermissionsHttpHeaders {
    /**
    * Specifies a value for the header key set in the Name field. If the request header value matches the Exact value, Consul applies the permission.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_intentions#exact ConfigEntryServiceIntentions#exact}
    */
    readonly exact?: string;
    /**
    * Inverts the matching logic configured in the Header.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_intentions#invert ConfigEntryServiceIntentions#invert}
    */
    readonly invert?: boolean | cdktf.IResolvable;
    /**
    * Specifies the name of the header to match.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_intentions#name ConfigEntryServiceIntentions#name}
    */
    readonly name: string;
    /**
    * Specifies a prefix value for the header key set in the Name field.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_intentions#prefix ConfigEntryServiceIntentions#prefix}
    */
    readonly prefix?: string;
    /**
    * Enables a match if the header configured in the Name field appears in the request. Consul matches on any value as long as the header key appears in the request.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_intentions#present ConfigEntryServiceIntentions#present}
    */
    readonly present?: boolean | cdktf.IResolvable;
    /**
    * Specifies a regular expression pattern as the value for the header key set in the Name field.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_intentions#regex ConfigEntryServiceIntentions#regex}
    */
    readonly regex?: string;
    /**
    * Specifies a suffix value for the header key set in the Name field.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_intentions#suffix ConfigEntryServiceIntentions#suffix}
    */
    readonly suffix?: string;
}
export declare function configEntryServiceIntentionsSourcesPermissionsHttpHeadersToTerraform(struct?: ConfigEntryServiceIntentionsSourcesPermissionsHttpHeaders | cdktf.IResolvable): any;
export declare function configEntryServiceIntentionsSourcesPermissionsHttpHeadersToHclTerraform(struct?: ConfigEntryServiceIntentionsSourcesPermissionsHttpHeaders | cdktf.IResolvable): any;
export declare class ConfigEntryServiceIntentionsSourcesPermissionsHttpHeadersOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ConfigEntryServiceIntentionsSourcesPermissionsHttpHeaders | cdktf.IResolvable | undefined;
    set internalValue(value: ConfigEntryServiceIntentionsSourcesPermissionsHttpHeaders | cdktf.IResolvable | undefined);
    private _exact?;
    get exact(): string;
    set exact(value: string);
    resetExact(): void;
    get exactInput(): string | undefined;
    private _invert?;
    get invert(): boolean | cdktf.IResolvable;
    set invert(value: boolean | cdktf.IResolvable);
    resetInvert(): void;
    get invertInput(): boolean | cdktf.IResolvable | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _prefix?;
    get prefix(): string;
    set prefix(value: string);
    resetPrefix(): void;
    get prefixInput(): string | undefined;
    private _present?;
    get present(): boolean | cdktf.IResolvable;
    set present(value: boolean | cdktf.IResolvable);
    resetPresent(): void;
    get presentInput(): boolean | cdktf.IResolvable | undefined;
    private _regex?;
    get regex(): string;
    set regex(value: string);
    resetRegex(): void;
    get regexInput(): string | undefined;
    private _suffix?;
    get suffix(): string;
    set suffix(value: string);
    resetSuffix(): void;
    get suffixInput(): string | undefined;
}
export declare class ConfigEntryServiceIntentionsSourcesPermissionsHttpHeadersList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ConfigEntryServiceIntentionsSourcesPermissionsHttpHeaders[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ConfigEntryServiceIntentionsSourcesPermissionsHttpHeadersOutputReference;
}
export interface ConfigEntryServiceIntentionsSourcesPermissionsHttp {
    /**
    * Specifies a list of HTTP methods.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_intentions#methods ConfigEntryServiceIntentions#methods}
    */
    readonly methods?: string[];
    /**
    * Specifies an exact path to match on the HTTP request path.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_intentions#path_exact ConfigEntryServiceIntentions#path_exact}
    */
    readonly pathExact?: string;
    /**
    * Specifies a path prefix to match on the HTTP request path.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_intentions#path_prefix ConfigEntryServiceIntentions#path_prefix}
    */
    readonly pathPrefix?: string;
    /**
    * Defines a regular expression to match on the HTTP request path.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_intentions#path_regex ConfigEntryServiceIntentions#path_regex}
    */
    readonly pathRegex?: string;
    /**
    * headers block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_intentions#headers ConfigEntryServiceIntentions#headers}
    */
    readonly headers?: ConfigEntryServiceIntentionsSourcesPermissionsHttpHeaders[] | cdktf.IResolvable;
}
export declare function configEntryServiceIntentionsSourcesPermissionsHttpToTerraform(struct?: ConfigEntryServiceIntentionsSourcesPermissionsHttp | cdktf.IResolvable): any;
export declare function configEntryServiceIntentionsSourcesPermissionsHttpToHclTerraform(struct?: ConfigEntryServiceIntentionsSourcesPermissionsHttp | cdktf.IResolvable): any;
export declare class ConfigEntryServiceIntentionsSourcesPermissionsHttpOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ConfigEntryServiceIntentionsSourcesPermissionsHttp | cdktf.IResolvable | undefined;
    set internalValue(value: ConfigEntryServiceIntentionsSourcesPermissionsHttp | cdktf.IResolvable | undefined);
    private _methods?;
    get methods(): string[];
    set methods(value: string[]);
    resetMethods(): void;
    get methodsInput(): string[] | undefined;
    private _pathExact?;
    get pathExact(): string;
    set pathExact(value: string);
    resetPathExact(): void;
    get pathExactInput(): string | undefined;
    private _pathPrefix?;
    get pathPrefix(): string;
    set pathPrefix(value: string);
    resetPathPrefix(): void;
    get pathPrefixInput(): string | undefined;
    private _pathRegex?;
    get pathRegex(): string;
    set pathRegex(value: string);
    resetPathRegex(): void;
    get pathRegexInput(): string | undefined;
    private _headers;
    get headers(): ConfigEntryServiceIntentionsSourcesPermissionsHttpHeadersList;
    putHeaders(value: ConfigEntryServiceIntentionsSourcesPermissionsHttpHeaders[] | cdktf.IResolvable): void;
    resetHeaders(): void;
    get headersInput(): cdktf.IResolvable | ConfigEntryServiceIntentionsSourcesPermissionsHttpHeaders[] | undefined;
}
export declare class ConfigEntryServiceIntentionsSourcesPermissionsHttpList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ConfigEntryServiceIntentionsSourcesPermissionsHttp[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ConfigEntryServiceIntentionsSourcesPermissionsHttpOutputReference;
}
export interface ConfigEntryServiceIntentionsSourcesPermissions {
    /**
    * Specifies the action to take when the source sends traffic to the destination service. The value is either allow or deny.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_intentions#action ConfigEntryServiceIntentions#action}
    */
    readonly action: string;
    /**
    * http block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_intentions#http ConfigEntryServiceIntentions#http}
    */
    readonly http: ConfigEntryServiceIntentionsSourcesPermissionsHttp[] | cdktf.IResolvable;
}
export declare function configEntryServiceIntentionsSourcesPermissionsToTerraform(struct?: ConfigEntryServiceIntentionsSourcesPermissions | cdktf.IResolvable): any;
export declare function configEntryServiceIntentionsSourcesPermissionsToHclTerraform(struct?: ConfigEntryServiceIntentionsSourcesPermissions | cdktf.IResolvable): any;
export declare class ConfigEntryServiceIntentionsSourcesPermissionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ConfigEntryServiceIntentionsSourcesPermissions | cdktf.IResolvable | undefined;
    set internalValue(value: ConfigEntryServiceIntentionsSourcesPermissions | cdktf.IResolvable | undefined);
    private _action?;
    get action(): string;
    set action(value: string);
    get actionInput(): string | undefined;
    private _http;
    get http(): ConfigEntryServiceIntentionsSourcesPermissionsHttpList;
    putHttp(value: ConfigEntryServiceIntentionsSourcesPermissionsHttp[] | cdktf.IResolvable): void;
    get httpInput(): cdktf.IResolvable | ConfigEntryServiceIntentionsSourcesPermissionsHttp[] | undefined;
}
export declare class ConfigEntryServiceIntentionsSourcesPermissionsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ConfigEntryServiceIntentionsSourcesPermissions[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ConfigEntryServiceIntentionsSourcesPermissionsOutputReference;
}
export interface ConfigEntryServiceIntentionsSources {
    /**
    * Specifies the action to take when the source sends traffic to the destination service.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_intentions#action ConfigEntryServiceIntentions#action}
    */
    readonly action?: string;
    /**
    * Specifies a description of the intention.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_intentions#description ConfigEntryServiceIntentions#description}
    */
    readonly description?: string;
    /**
    * Specifies the name of the source that the intention allows or denies traffic from.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_intentions#name ConfigEntryServiceIntentions#name}
    */
    readonly name?: string;
    /**
    * Specifies the traffic source namespace that the intention allows or denies traffic from.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_intentions#namespace ConfigEntryServiceIntentions#namespace}
    */
    readonly namespace?: string;
    /**
    * Specifies the name of an admin partition that the intention allows or denies traffic from.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_intentions#partition ConfigEntryServiceIntentions#partition}
    */
    readonly partition?: string;
    /**
    * Specifies the name of a peered Consul cluster that the intention allows or denies traffic from
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_intentions#peer ConfigEntryServiceIntentions#peer}
    */
    readonly peer?: string;
    /**
    * The Precedence field contains a read-only integer. Consul generates the value based on name configurations for the source and destination services.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_intentions#precedence ConfigEntryServiceIntentions#precedence}
    */
    readonly precedence?: number;
    /**
    * Specifies the name of a sameness group that the intention allows or denies traffic from.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_intentions#sameness_group ConfigEntryServiceIntentions#sameness_group}
    */
    readonly samenessGroup?: string;
    /**
    * Specifies the type of destination service that the configuration entry applies to.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_intentions#type ConfigEntryServiceIntentions#type}
    */
    readonly type?: string;
    /**
    * permissions block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_intentions#permissions ConfigEntryServiceIntentions#permissions}
    */
    readonly permissions?: ConfigEntryServiceIntentionsSourcesPermissions[] | cdktf.IResolvable;
}
export declare function configEntryServiceIntentionsSourcesToTerraform(struct?: ConfigEntryServiceIntentionsSources | cdktf.IResolvable): any;
export declare function configEntryServiceIntentionsSourcesToHclTerraform(struct?: ConfigEntryServiceIntentionsSources | cdktf.IResolvable): any;
export declare class ConfigEntryServiceIntentionsSourcesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ConfigEntryServiceIntentionsSources | cdktf.IResolvable | undefined;
    set internalValue(value: ConfigEntryServiceIntentionsSources | cdktf.IResolvable | undefined);
    private _action?;
    get action(): string;
    set action(value: string);
    resetAction(): void;
    get actionInput(): string | undefined;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
    private _namespace?;
    get namespace(): string;
    set namespace(value: string);
    resetNamespace(): void;
    get namespaceInput(): string | undefined;
    private _partition?;
    get partition(): string;
    set partition(value: string);
    resetPartition(): void;
    get partitionInput(): string | undefined;
    private _peer?;
    get peer(): string;
    set peer(value: string);
    resetPeer(): void;
    get peerInput(): string | undefined;
    private _precedence?;
    get precedence(): number;
    set precedence(value: number);
    resetPrecedence(): void;
    get precedenceInput(): number | undefined;
    private _samenessGroup?;
    get samenessGroup(): string;
    set samenessGroup(value: string);
    resetSamenessGroup(): void;
    get samenessGroupInput(): string | undefined;
    private _type?;
    get type(): string;
    set type(value: string);
    resetType(): void;
    get typeInput(): string | undefined;
    private _permissions;
    get permissions(): ConfigEntryServiceIntentionsSourcesPermissionsList;
    putPermissions(value: ConfigEntryServiceIntentionsSourcesPermissions[] | cdktf.IResolvable): void;
    resetPermissions(): void;
    get permissionsInput(): cdktf.IResolvable | ConfigEntryServiceIntentionsSourcesPermissions[] | undefined;
}
export declare class ConfigEntryServiceIntentionsSourcesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ConfigEntryServiceIntentionsSources[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ConfigEntryServiceIntentionsSourcesOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_intentions consul_config_entry_service_intentions}
*/
export declare class ConfigEntryServiceIntentions extends cdktf.TerraformResource {
    static readonly tfResourceType = "consul_config_entry_service_intentions";
    /**
    * Generates CDKTF code for importing a ConfigEntryServiceIntentions resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the ConfigEntryServiceIntentions to import
    * @param importFromId The id of the existing ConfigEntryServiceIntentions that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_intentions#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the ConfigEntryServiceIntentions to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_intentions consul_config_entry_service_intentions} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options ConfigEntryServiceIntentionsConfig
    */
    constructor(scope: Construct, id: string, config: ConfigEntryServiceIntentionsConfig);
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _meta?;
    get meta(): {
        [key: string]: string;
    };
    set meta(value: {
        [key: string]: string;
    });
    resetMeta(): void;
    get metaInput(): {
        [key: string]: string;
    } | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _namespace?;
    get namespace(): string;
    set namespace(value: string);
    resetNamespace(): void;
    get namespaceInput(): string | undefined;
    private _partition?;
    get partition(): string;
    set partition(value: string);
    resetPartition(): void;
    get partitionInput(): string | undefined;
    private _jwt;
    get jwt(): ConfigEntryServiceIntentionsJwtList;
    putJwt(value: ConfigEntryServiceIntentionsJwt[] | cdktf.IResolvable): void;
    resetJwt(): void;
    get jwtInput(): cdktf.IResolvable | ConfigEntryServiceIntentionsJwt[] | undefined;
    private _sources;
    get sources(): ConfigEntryServiceIntentionsSourcesList;
    putSources(value: ConfigEntryServiceIntentionsSources[] | cdktf.IResolvable): void;
    resetSources(): void;
    get sourcesInput(): cdktf.IResolvable | ConfigEntryServiceIntentionsSources[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
