/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface ConfigEntryServiceResolverConfig extends cdktf.TerraformMetaArguments {
    /**
    * Specifies the timeout duration for establishing new network connections to this service.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_resolver#connect_timeout ConfigEntryServiceResolver#connect_timeout}
    */
    readonly connectTimeout?: string;
    /**
    * Specifies a defined subset of service instances to use when no explicit subset is requested. If this parameter is not specified, Consul uses the unnamed default subset.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_resolver#default_subset ConfigEntryServiceResolver#default_subset}
    */
    readonly defaultSubset?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_resolver#id ConfigEntryServiceResolver#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Specifies key-value pairs to add to the KV store.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_resolver#meta ConfigEntryServiceResolver#meta}
    */
    readonly meta?: {
        [key: string]: string;
    };
    /**
    * Specifies a name for the configuration entry.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_resolver#name ConfigEntryServiceResolver#name}
    */
    readonly name: string;
    /**
    * Specifies the namespace that the service resolver applies to.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_resolver#namespace ConfigEntryServiceResolver#namespace}
    */
    readonly namespace?: string;
    /**
    * Specifies the admin partition that the service resolver applies to.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_resolver#partition ConfigEntryServiceResolver#partition}
    */
    readonly partition?: string;
    /**
    * Specifies the timeout duration for receiving an HTTP response from this service.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_resolver#request_timeout ConfigEntryServiceResolver#request_timeout}
    */
    readonly requestTimeout?: string;
    /**
    * failover block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_resolver#failover ConfigEntryServiceResolver#failover}
    */
    readonly failover?: ConfigEntryServiceResolverFailover[] | cdktf.IResolvable;
    /**
    * load_balancer block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_resolver#load_balancer ConfigEntryServiceResolver#load_balancer}
    */
    readonly loadBalancer?: ConfigEntryServiceResolverLoadBalancer[] | cdktf.IResolvable;
    /**
    * redirect block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_resolver#redirect ConfigEntryServiceResolver#redirect}
    */
    readonly redirect?: ConfigEntryServiceResolverRedirect[] | cdktf.IResolvable;
    /**
    * subsets block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_resolver#subsets ConfigEntryServiceResolver#subsets}
    */
    readonly subsets?: ConfigEntryServiceResolverSubsets[] | cdktf.IResolvable;
}
export interface ConfigEntryServiceResolverFailoverTargets {
    /**
    * Specifies the WAN federated datacenter to use for the failover target. If empty, the current datacenter is used.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_resolver#datacenter ConfigEntryServiceResolver#datacenter}
    */
    readonly datacenter?: string;
    /**
    * Specifies the namespace to use for the failover target. If empty, the default namespace is used.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_resolver#namespace ConfigEntryServiceResolver#namespace}
    */
    readonly namespace?: string;
    /**
    * Specifies the admin partition within the same datacenter to use for the failover target. If empty, the default partition is used.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_resolver#partition ConfigEntryServiceResolver#partition}
    */
    readonly partition?: string;
    /**
    * Specifies the destination cluster peer to resolve the target service name from.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_resolver#peer ConfigEntryServiceResolver#peer}
    */
    readonly peer?: string;
    /**
    * Specifies the service name to use for the failover target. If empty, the current service name is used.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_resolver#service ConfigEntryServiceResolver#service}
    */
    readonly service?: string;
    /**
    * Specifies the named subset to use for the failover target. If empty, the default subset for the requested service name is used.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_resolver#service_subset ConfigEntryServiceResolver#service_subset}
    */
    readonly serviceSubset?: string;
}
export declare function configEntryServiceResolverFailoverTargetsToTerraform(struct?: ConfigEntryServiceResolverFailoverTargets | cdktf.IResolvable): any;
export declare function configEntryServiceResolverFailoverTargetsToHclTerraform(struct?: ConfigEntryServiceResolverFailoverTargets | cdktf.IResolvable): any;
export declare class ConfigEntryServiceResolverFailoverTargetsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ConfigEntryServiceResolverFailoverTargets | cdktf.IResolvable | undefined;
    set internalValue(value: ConfigEntryServiceResolverFailoverTargets | cdktf.IResolvable | undefined);
    private _datacenter?;
    get datacenter(): string;
    set datacenter(value: string);
    resetDatacenter(): void;
    get datacenterInput(): string | undefined;
    private _namespace?;
    get namespace(): string;
    set namespace(value: string);
    resetNamespace(): void;
    get namespaceInput(): string | undefined;
    private _partition?;
    get partition(): string;
    set partition(value: string);
    resetPartition(): void;
    get partitionInput(): string | undefined;
    private _peer?;
    get peer(): string;
    set peer(value: string);
    resetPeer(): void;
    get peerInput(): string | undefined;
    private _service?;
    get service(): string;
    set service(value: string);
    resetService(): void;
    get serviceInput(): string | undefined;
    private _serviceSubset?;
    get serviceSubset(): string;
    set serviceSubset(value: string);
    resetServiceSubset(): void;
    get serviceSubsetInput(): string | undefined;
}
export declare class ConfigEntryServiceResolverFailoverTargetsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ConfigEntryServiceResolverFailoverTargets[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ConfigEntryServiceResolverFailoverTargetsOutputReference;
}
export interface ConfigEntryServiceResolverFailover {
    /**
    * Specifies an ordered list of datacenters at the failover location to attempt connections to during a failover scenario. When Consul cannot establish a connection with the first datacenter in the list, it proceeds sequentially until establishing a connection with another datacenter.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_resolver#datacenters ConfigEntryServiceResolver#datacenters}
    */
    readonly datacenters?: string[];
    /**
    * Specifies the namespace at the failover location where the failover services are deployed.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_resolver#namespace ConfigEntryServiceResolver#namespace}
    */
    readonly namespace?: string;
    /**
    * Specifies the sameness group at the failover location where the failover services are deployed.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_resolver#sameness_group ConfigEntryServiceResolver#sameness_group}
    */
    readonly samenessGroup?: string;
    /**
    * Specifies the name of the service to resolve at the failover location during a failover scenario.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_resolver#service ConfigEntryServiceResolver#service}
    */
    readonly service?: string;
    /**
    * Specifies the name of a subset of service instances to resolve at the failover location during a failover scenario.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_resolver#service_subset ConfigEntryServiceResolver#service_subset}
    */
    readonly serviceSubset?: string;
    /**
    * Name of subset.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_resolver#subset_name ConfigEntryServiceResolver#subset_name}
    */
    readonly subsetName: string;
    /**
    * targets block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_resolver#targets ConfigEntryServiceResolver#targets}
    */
    readonly targets?: ConfigEntryServiceResolverFailoverTargets[] | cdktf.IResolvable;
}
export declare function configEntryServiceResolverFailoverToTerraform(struct?: ConfigEntryServiceResolverFailover | cdktf.IResolvable): any;
export declare function configEntryServiceResolverFailoverToHclTerraform(struct?: ConfigEntryServiceResolverFailover | cdktf.IResolvable): any;
export declare class ConfigEntryServiceResolverFailoverOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ConfigEntryServiceResolverFailover | cdktf.IResolvable | undefined;
    set internalValue(value: ConfigEntryServiceResolverFailover | cdktf.IResolvable | undefined);
    private _datacenters?;
    get datacenters(): string[];
    set datacenters(value: string[]);
    resetDatacenters(): void;
    get datacentersInput(): string[] | undefined;
    private _namespace?;
    get namespace(): string;
    set namespace(value: string);
    resetNamespace(): void;
    get namespaceInput(): string | undefined;
    private _samenessGroup?;
    get samenessGroup(): string;
    set samenessGroup(value: string);
    resetSamenessGroup(): void;
    get samenessGroupInput(): string | undefined;
    private _service?;
    get service(): string;
    set service(value: string);
    resetService(): void;
    get serviceInput(): string | undefined;
    private _serviceSubset?;
    get serviceSubset(): string;
    set serviceSubset(value: string);
    resetServiceSubset(): void;
    get serviceSubsetInput(): string | undefined;
    private _subsetName?;
    get subsetName(): string;
    set subsetName(value: string);
    get subsetNameInput(): string | undefined;
    private _targets;
    get targets(): ConfigEntryServiceResolverFailoverTargetsList;
    putTargets(value: ConfigEntryServiceResolverFailoverTargets[] | cdktf.IResolvable): void;
    resetTargets(): void;
    get targetsInput(): cdktf.IResolvable | ConfigEntryServiceResolverFailoverTargets[] | undefined;
}
export declare class ConfigEntryServiceResolverFailoverList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ConfigEntryServiceResolverFailover[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ConfigEntryServiceResolverFailoverOutputReference;
}
export interface ConfigEntryServiceResolverLoadBalancerHashPoliciesCookieConfig {
    /**
    * Specifies the path to set for the cookie.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_resolver#path ConfigEntryServiceResolver#path}
    */
    readonly path?: string;
    /**
    * Directs Consul to generate a session cookie with no expiration.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_resolver#session ConfigEntryServiceResolver#session}
    */
    readonly session?: boolean | cdktf.IResolvable;
    /**
    * Specifies the TTL for generated cookies. Cannot be specified for session cookies.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_resolver#ttl ConfigEntryServiceResolver#ttl}
    */
    readonly ttl?: string;
}
export declare function configEntryServiceResolverLoadBalancerHashPoliciesCookieConfigToTerraform(struct?: ConfigEntryServiceResolverLoadBalancerHashPoliciesCookieConfig | cdktf.IResolvable): any;
export declare function configEntryServiceResolverLoadBalancerHashPoliciesCookieConfigToHclTerraform(struct?: ConfigEntryServiceResolverLoadBalancerHashPoliciesCookieConfig | cdktf.IResolvable): any;
export declare class ConfigEntryServiceResolverLoadBalancerHashPoliciesCookieConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ConfigEntryServiceResolverLoadBalancerHashPoliciesCookieConfig | cdktf.IResolvable | undefined;
    set internalValue(value: ConfigEntryServiceResolverLoadBalancerHashPoliciesCookieConfig | cdktf.IResolvable | undefined);
    private _path?;
    get path(): string;
    set path(value: string);
    resetPath(): void;
    get pathInput(): string | undefined;
    private _session?;
    get session(): boolean | cdktf.IResolvable;
    set session(value: boolean | cdktf.IResolvable);
    resetSession(): void;
    get sessionInput(): boolean | cdktf.IResolvable | undefined;
    private _ttl?;
    get ttl(): string;
    set ttl(value: string);
    resetTtl(): void;
    get ttlInput(): string | undefined;
}
export declare class ConfigEntryServiceResolverLoadBalancerHashPoliciesCookieConfigList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ConfigEntryServiceResolverLoadBalancerHashPoliciesCookieConfig[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ConfigEntryServiceResolverLoadBalancerHashPoliciesCookieConfigOutputReference;
}
export interface ConfigEntryServiceResolverLoadBalancerHashPolicies {
    /**
    * Specifies the attribute type to hash on. You cannot specify the Field parameter if SourceIP is also configured.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_resolver#field ConfigEntryServiceResolver#field}
    */
    readonly field?: string;
    /**
    * Specifies the value to hash, such as a header name, cookie name, or a URL query parameter name.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_resolver#field_value ConfigEntryServiceResolver#field_value}
    */
    readonly fieldValue?: string;
    /**
    * Determines if the hash type should be source IP address.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_resolver#source_ip ConfigEntryServiceResolver#source_ip}
    */
    readonly sourceIp?: boolean | cdktf.IResolvable;
    /**
    * Determines if Consul should stop computing the hash when multiple hash policies are present.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_resolver#terminal ConfigEntryServiceResolver#terminal}
    */
    readonly terminal?: boolean | cdktf.IResolvable;
    /**
    * cookie_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_resolver#cookie_config ConfigEntryServiceResolver#cookie_config}
    */
    readonly cookieConfig?: ConfigEntryServiceResolverLoadBalancerHashPoliciesCookieConfig[] | cdktf.IResolvable;
}
export declare function configEntryServiceResolverLoadBalancerHashPoliciesToTerraform(struct?: ConfigEntryServiceResolverLoadBalancerHashPolicies | cdktf.IResolvable): any;
export declare function configEntryServiceResolverLoadBalancerHashPoliciesToHclTerraform(struct?: ConfigEntryServiceResolverLoadBalancerHashPolicies | cdktf.IResolvable): any;
export declare class ConfigEntryServiceResolverLoadBalancerHashPoliciesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ConfigEntryServiceResolverLoadBalancerHashPolicies | cdktf.IResolvable | undefined;
    set internalValue(value: ConfigEntryServiceResolverLoadBalancerHashPolicies | cdktf.IResolvable | undefined);
    private _field?;
    get field(): string;
    set field(value: string);
    resetField(): void;
    get fieldInput(): string | undefined;
    private _fieldValue?;
    get fieldValue(): string;
    set fieldValue(value: string);
    resetFieldValue(): void;
    get fieldValueInput(): string | undefined;
    private _sourceIp?;
    get sourceIp(): boolean | cdktf.IResolvable;
    set sourceIp(value: boolean | cdktf.IResolvable);
    resetSourceIp(): void;
    get sourceIpInput(): boolean | cdktf.IResolvable | undefined;
    private _terminal?;
    get terminal(): boolean | cdktf.IResolvable;
    set terminal(value: boolean | cdktf.IResolvable);
    resetTerminal(): void;
    get terminalInput(): boolean | cdktf.IResolvable | undefined;
    private _cookieConfig;
    get cookieConfig(): ConfigEntryServiceResolverLoadBalancerHashPoliciesCookieConfigList;
    putCookieConfig(value: ConfigEntryServiceResolverLoadBalancerHashPoliciesCookieConfig[] | cdktf.IResolvable): void;
    resetCookieConfig(): void;
    get cookieConfigInput(): cdktf.IResolvable | ConfigEntryServiceResolverLoadBalancerHashPoliciesCookieConfig[] | undefined;
}
export declare class ConfigEntryServiceResolverLoadBalancerHashPoliciesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ConfigEntryServiceResolverLoadBalancerHashPolicies[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ConfigEntryServiceResolverLoadBalancerHashPoliciesOutputReference;
}
export interface ConfigEntryServiceResolverLoadBalancerLeastRequestConfig {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_resolver#choice_count ConfigEntryServiceResolver#choice_count}
    */
    readonly choiceCount?: number;
}
export declare function configEntryServiceResolverLoadBalancerLeastRequestConfigToTerraform(struct?: ConfigEntryServiceResolverLoadBalancerLeastRequestConfig | cdktf.IResolvable): any;
export declare function configEntryServiceResolverLoadBalancerLeastRequestConfigToHclTerraform(struct?: ConfigEntryServiceResolverLoadBalancerLeastRequestConfig | cdktf.IResolvable): any;
export declare class ConfigEntryServiceResolverLoadBalancerLeastRequestConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ConfigEntryServiceResolverLoadBalancerLeastRequestConfig | cdktf.IResolvable | undefined;
    set internalValue(value: ConfigEntryServiceResolverLoadBalancerLeastRequestConfig | cdktf.IResolvable | undefined);
    private _choiceCount?;
    get choiceCount(): number;
    set choiceCount(value: number);
    resetChoiceCount(): void;
    get choiceCountInput(): number | undefined;
}
export declare class ConfigEntryServiceResolverLoadBalancerLeastRequestConfigList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ConfigEntryServiceResolverLoadBalancerLeastRequestConfig[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ConfigEntryServiceResolverLoadBalancerLeastRequestConfigOutputReference;
}
export interface ConfigEntryServiceResolverLoadBalancerRingHashConfig {
    /**
    * Determines the maximum number of entries in the hash ring.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_resolver#maximum_ring_size ConfigEntryServiceResolver#maximum_ring_size}
    */
    readonly maximumRingSize?: number;
    /**
    * Determines the minimum number of entries in the hash ring.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_resolver#minimum_ring_size ConfigEntryServiceResolver#minimum_ring_size}
    */
    readonly minimumRingSize?: number;
}
export declare function configEntryServiceResolverLoadBalancerRingHashConfigToTerraform(struct?: ConfigEntryServiceResolverLoadBalancerRingHashConfig | cdktf.IResolvable): any;
export declare function configEntryServiceResolverLoadBalancerRingHashConfigToHclTerraform(struct?: ConfigEntryServiceResolverLoadBalancerRingHashConfig | cdktf.IResolvable): any;
export declare class ConfigEntryServiceResolverLoadBalancerRingHashConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ConfigEntryServiceResolverLoadBalancerRingHashConfig | cdktf.IResolvable | undefined;
    set internalValue(value: ConfigEntryServiceResolverLoadBalancerRingHashConfig | cdktf.IResolvable | undefined);
    private _maximumRingSize?;
    get maximumRingSize(): number;
    set maximumRingSize(value: number);
    resetMaximumRingSize(): void;
    get maximumRingSizeInput(): number | undefined;
    private _minimumRingSize?;
    get minimumRingSize(): number;
    set minimumRingSize(value: number);
    resetMinimumRingSize(): void;
    get minimumRingSizeInput(): number | undefined;
}
export declare class ConfigEntryServiceResolverLoadBalancerRingHashConfigList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ConfigEntryServiceResolverLoadBalancerRingHashConfig[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ConfigEntryServiceResolverLoadBalancerRingHashConfigOutputReference;
}
export interface ConfigEntryServiceResolverLoadBalancer {
    /**
    * Specifies the type of load balancing policy for selecting a host.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_resolver#policy ConfigEntryServiceResolver#policy}
    */
    readonly policy?: string;
    /**
    * hash_policies block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_resolver#hash_policies ConfigEntryServiceResolver#hash_policies}
    */
    readonly hashPolicies?: ConfigEntryServiceResolverLoadBalancerHashPolicies[] | cdktf.IResolvable;
    /**
    * least_request_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_resolver#least_request_config ConfigEntryServiceResolver#least_request_config}
    */
    readonly leastRequestConfig?: ConfigEntryServiceResolverLoadBalancerLeastRequestConfig[] | cdktf.IResolvable;
    /**
    * ring_hash_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_resolver#ring_hash_config ConfigEntryServiceResolver#ring_hash_config}
    */
    readonly ringHashConfig?: ConfigEntryServiceResolverLoadBalancerRingHashConfig[] | cdktf.IResolvable;
}
export declare function configEntryServiceResolverLoadBalancerToTerraform(struct?: ConfigEntryServiceResolverLoadBalancer | cdktf.IResolvable): any;
export declare function configEntryServiceResolverLoadBalancerToHclTerraform(struct?: ConfigEntryServiceResolverLoadBalancer | cdktf.IResolvable): any;
export declare class ConfigEntryServiceResolverLoadBalancerOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ConfigEntryServiceResolverLoadBalancer | cdktf.IResolvable | undefined;
    set internalValue(value: ConfigEntryServiceResolverLoadBalancer | cdktf.IResolvable | undefined);
    private _policy?;
    get policy(): string;
    set policy(value: string);
    resetPolicy(): void;
    get policyInput(): string | undefined;
    private _hashPolicies;
    get hashPolicies(): ConfigEntryServiceResolverLoadBalancerHashPoliciesList;
    putHashPolicies(value: ConfigEntryServiceResolverLoadBalancerHashPolicies[] | cdktf.IResolvable): void;
    resetHashPolicies(): void;
    get hashPoliciesInput(): cdktf.IResolvable | ConfigEntryServiceResolverLoadBalancerHashPolicies[] | undefined;
    private _leastRequestConfig;
    get leastRequestConfig(): ConfigEntryServiceResolverLoadBalancerLeastRequestConfigList;
    putLeastRequestConfig(value: ConfigEntryServiceResolverLoadBalancerLeastRequestConfig[] | cdktf.IResolvable): void;
    resetLeastRequestConfig(): void;
    get leastRequestConfigInput(): cdktf.IResolvable | ConfigEntryServiceResolverLoadBalancerLeastRequestConfig[] | undefined;
    private _ringHashConfig;
    get ringHashConfig(): ConfigEntryServiceResolverLoadBalancerRingHashConfigList;
    putRingHashConfig(value: ConfigEntryServiceResolverLoadBalancerRingHashConfig[] | cdktf.IResolvable): void;
    resetRingHashConfig(): void;
    get ringHashConfigInput(): cdktf.IResolvable | ConfigEntryServiceResolverLoadBalancerRingHashConfig[] | undefined;
}
export declare class ConfigEntryServiceResolverLoadBalancerList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ConfigEntryServiceResolverLoadBalancer[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ConfigEntryServiceResolverLoadBalancerOutputReference;
}
export interface ConfigEntryServiceResolverRedirect {
    /**
    * Specifies the datacenter at the redirect’s destination that resolves local upstream requests.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_resolver#datacenter ConfigEntryServiceResolver#datacenter}
    */
    readonly datacenter?: string;
    /**
    * Specifies the namespace at the redirect’s destination that resolves local upstream requests.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_resolver#namespace ConfigEntryServiceResolver#namespace}
    */
    readonly namespace?: string;
    /**
    * Specifies the admin partition at the redirect’s destination that resolves local upstream requests.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_resolver#partition ConfigEntryServiceResolver#partition}
    */
    readonly partition?: string;
    /**
    * Specifies the cluster with an active cluster peering connection at the redirect’s destination that resolves local upstream requests.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_resolver#peer ConfigEntryServiceResolver#peer}
    */
    readonly peer?: string;
    /**
    * Specifies the sameness group at the redirect’s destination that resolves local upstream requests.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_resolver#sameness_group ConfigEntryServiceResolver#sameness_group}
    */
    readonly samenessGroup?: string;
    /**
    * Specifies the name of a service at the redirect’s destination that resolves local upstream requests.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_resolver#service ConfigEntryServiceResolver#service}
    */
    readonly service?: string;
    /**
    * Specifies the name of a subset of services at the redirect’s destination that resolves local upstream requests. If empty, the default subset is used. If specified, you must also specify at least one of the following in the same Redirect map: Service, Namespace, andDatacenter.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_resolver#service_subset ConfigEntryServiceResolver#service_subset}
    */
    readonly serviceSubset?: string;
}
export declare function configEntryServiceResolverRedirectToTerraform(struct?: ConfigEntryServiceResolverRedirect | cdktf.IResolvable): any;
export declare function configEntryServiceResolverRedirectToHclTerraform(struct?: ConfigEntryServiceResolverRedirect | cdktf.IResolvable): any;
export declare class ConfigEntryServiceResolverRedirectOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ConfigEntryServiceResolverRedirect | cdktf.IResolvable | undefined;
    set internalValue(value: ConfigEntryServiceResolverRedirect | cdktf.IResolvable | undefined);
    private _datacenter?;
    get datacenter(): string;
    set datacenter(value: string);
    resetDatacenter(): void;
    get datacenterInput(): string | undefined;
    private _namespace?;
    get namespace(): string;
    set namespace(value: string);
    resetNamespace(): void;
    get namespaceInput(): string | undefined;
    private _partition?;
    get partition(): string;
    set partition(value: string);
    resetPartition(): void;
    get partitionInput(): string | undefined;
    private _peer?;
    get peer(): string;
    set peer(value: string);
    resetPeer(): void;
    get peerInput(): string | undefined;
    private _samenessGroup?;
    get samenessGroup(): string;
    set samenessGroup(value: string);
    resetSamenessGroup(): void;
    get samenessGroupInput(): string | undefined;
    private _service?;
    get service(): string;
    set service(value: string);
    resetService(): void;
    get serviceInput(): string | undefined;
    private _serviceSubset?;
    get serviceSubset(): string;
    set serviceSubset(value: string);
    resetServiceSubset(): void;
    get serviceSubsetInput(): string | undefined;
}
export declare class ConfigEntryServiceResolverRedirectList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ConfigEntryServiceResolverRedirect[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ConfigEntryServiceResolverRedirectOutputReference;
}
export interface ConfigEntryServiceResolverSubsets {
    /**
    * Specifies an expression that filters the DNS elements of service instances that belong to the subset. If empty, all healthy instances of a service are returned.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_resolver#filter ConfigEntryServiceResolver#filter}
    */
    readonly filter: string;
    /**
    * Name of subset.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_resolver#name ConfigEntryServiceResolver#name}
    */
    readonly name: string;
    /**
    * Determines if instances that return a warning from a health check are allowed to resolve a request. When set to false, instances with passing and warning states are considered healthy. When set to true, only instances with a passing health check state are considered healthy.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_resolver#only_passing ConfigEntryServiceResolver#only_passing}
    */
    readonly onlyPassing: boolean | cdktf.IResolvable;
}
export declare function configEntryServiceResolverSubsetsToTerraform(struct?: ConfigEntryServiceResolverSubsets | cdktf.IResolvable): any;
export declare function configEntryServiceResolverSubsetsToHclTerraform(struct?: ConfigEntryServiceResolverSubsets | cdktf.IResolvable): any;
export declare class ConfigEntryServiceResolverSubsetsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ConfigEntryServiceResolverSubsets | cdktf.IResolvable | undefined;
    set internalValue(value: ConfigEntryServiceResolverSubsets | cdktf.IResolvable | undefined);
    private _filter?;
    get filter(): string;
    set filter(value: string);
    get filterInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _onlyPassing?;
    get onlyPassing(): boolean | cdktf.IResolvable;
    set onlyPassing(value: boolean | cdktf.IResolvable);
    get onlyPassingInput(): boolean | cdktf.IResolvable | undefined;
}
export declare class ConfigEntryServiceResolverSubsetsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ConfigEntryServiceResolverSubsets[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ConfigEntryServiceResolverSubsetsOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_resolver consul_config_entry_service_resolver}
*/
export declare class ConfigEntryServiceResolver extends cdktf.TerraformResource {
    static readonly tfResourceType = "consul_config_entry_service_resolver";
    /**
    * Generates CDKTF code for importing a ConfigEntryServiceResolver resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the ConfigEntryServiceResolver to import
    * @param importFromId The id of the existing ConfigEntryServiceResolver that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_resolver#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the ConfigEntryServiceResolver to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_resolver consul_config_entry_service_resolver} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options ConfigEntryServiceResolverConfig
    */
    constructor(scope: Construct, id: string, config: ConfigEntryServiceResolverConfig);
    private _connectTimeout?;
    get connectTimeout(): string;
    set connectTimeout(value: string);
    resetConnectTimeout(): void;
    get connectTimeoutInput(): string | undefined;
    private _defaultSubset?;
    get defaultSubset(): string;
    set defaultSubset(value: string);
    resetDefaultSubset(): void;
    get defaultSubsetInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _meta?;
    get meta(): {
        [key: string]: string;
    };
    set meta(value: {
        [key: string]: string;
    });
    resetMeta(): void;
    get metaInput(): {
        [key: string]: string;
    } | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _namespace?;
    get namespace(): string;
    set namespace(value: string);
    resetNamespace(): void;
    get namespaceInput(): string | undefined;
    private _partition?;
    get partition(): string;
    set partition(value: string);
    resetPartition(): void;
    get partitionInput(): string | undefined;
    private _requestTimeout?;
    get requestTimeout(): string;
    set requestTimeout(value: string);
    resetRequestTimeout(): void;
    get requestTimeoutInput(): string | undefined;
    private _failover;
    get failover(): ConfigEntryServiceResolverFailoverList;
    putFailover(value: ConfigEntryServiceResolverFailover[] | cdktf.IResolvable): void;
    resetFailover(): void;
    get failoverInput(): cdktf.IResolvable | ConfigEntryServiceResolverFailover[] | undefined;
    private _loadBalancer;
    get loadBalancer(): ConfigEntryServiceResolverLoadBalancerList;
    putLoadBalancer(value: ConfigEntryServiceResolverLoadBalancer[] | cdktf.IResolvable): void;
    resetLoadBalancer(): void;
    get loadBalancerInput(): cdktf.IResolvable | ConfigEntryServiceResolverLoadBalancer[] | undefined;
    private _redirect;
    get redirect(): ConfigEntryServiceResolverRedirectList;
    putRedirect(value: ConfigEntryServiceResolverRedirect[] | cdktf.IResolvable): void;
    resetRedirect(): void;
    get redirectInput(): cdktf.IResolvable | ConfigEntryServiceResolverRedirect[] | undefined;
    private _subsets;
    get subsets(): ConfigEntryServiceResolverSubsetsList;
    putSubsets(value: ConfigEntryServiceResolverSubsets[] | cdktf.IResolvable): void;
    resetSubsets(): void;
    get subsetsInput(): cdktf.IResolvable | ConfigEntryServiceResolverSubsets[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
