/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface ConfigEntryServiceRouterConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_router#id ConfigEntryServiceRouter#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Specifies key-value pairs to add to the KV store.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_router#meta ConfigEntryServiceRouter#meta}
    */
    readonly meta?: {
        [key: string]: string;
    };
    /**
    * Specifies a name for the configuration entry.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_router#name ConfigEntryServiceRouter#name}
    */
    readonly name: string;
    /**
    * Specifies the namespace to apply the configuration entry.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_router#namespace ConfigEntryServiceRouter#namespace}
    */
    readonly namespace?: string;
    /**
    * Specifies the admin partition to apply the configuration entry.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_router#partition ConfigEntryServiceRouter#partition}
    */
    readonly partition?: string;
    /**
    * routes block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_router#routes ConfigEntryServiceRouter#routes}
    */
    readonly routes?: ConfigEntryServiceRouterRoutes[] | cdktf.IResolvable;
}
export interface ConfigEntryServiceRouterRoutesDestinationRequestHeaders {
    /**
    * Defines a set of key-value pairs to add to the header. Use header names as the keys.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_router#add ConfigEntryServiceRouter#add}
    */
    readonly add?: {
        [key: string]: string;
    };
    /**
    * Defines a list of headers to remove.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_router#remove ConfigEntryServiceRouter#remove}
    */
    readonly remove?: string[];
    /**
    * Defines a set of key-value pairs to add to the request header or to replace existing header values with.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_router#set ConfigEntryServiceRouter#set}
    */
    readonly set?: {
        [key: string]: string;
    };
}
export declare function configEntryServiceRouterRoutesDestinationRequestHeadersToTerraform(struct?: ConfigEntryServiceRouterRoutesDestinationRequestHeadersOutputReference | ConfigEntryServiceRouterRoutesDestinationRequestHeaders): any;
export declare function configEntryServiceRouterRoutesDestinationRequestHeadersToHclTerraform(struct?: ConfigEntryServiceRouterRoutesDestinationRequestHeadersOutputReference | ConfigEntryServiceRouterRoutesDestinationRequestHeaders): any;
export declare class ConfigEntryServiceRouterRoutesDestinationRequestHeadersOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ConfigEntryServiceRouterRoutesDestinationRequestHeaders | undefined;
    set internalValue(value: ConfigEntryServiceRouterRoutesDestinationRequestHeaders | undefined);
    private _add?;
    get add(): {
        [key: string]: string;
    };
    set add(value: {
        [key: string]: string;
    });
    resetAdd(): void;
    get addInput(): {
        [key: string]: string;
    } | undefined;
    private _remove?;
    get remove(): string[];
    set remove(value: string[]);
    resetRemove(): void;
    get removeInput(): string[] | undefined;
    private _set?;
    get set(): {
        [key: string]: string;
    };
    set set(value: {
        [key: string]: string;
    });
    resetSet(): void;
    get setInput(): {
        [key: string]: string;
    } | undefined;
}
export interface ConfigEntryServiceRouterRoutesDestinationResponseHeaders {
    /**
    * Defines a set of key-value pairs to add to the header. Use header names as the keys
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_router#add ConfigEntryServiceRouter#add}
    */
    readonly add?: {
        [key: string]: string;
    };
    /**
    * Defines a list of headers to remove.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_router#remove ConfigEntryServiceRouter#remove}
    */
    readonly remove?: string[];
    /**
    * Defines a set of key-value pairs to add to the response header or to replace existing header values with
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_router#set ConfigEntryServiceRouter#set}
    */
    readonly set?: {
        [key: string]: string;
    };
}
export declare function configEntryServiceRouterRoutesDestinationResponseHeadersToTerraform(struct?: ConfigEntryServiceRouterRoutesDestinationResponseHeadersOutputReference | ConfigEntryServiceRouterRoutesDestinationResponseHeaders): any;
export declare function configEntryServiceRouterRoutesDestinationResponseHeadersToHclTerraform(struct?: ConfigEntryServiceRouterRoutesDestinationResponseHeadersOutputReference | ConfigEntryServiceRouterRoutesDestinationResponseHeaders): any;
export declare class ConfigEntryServiceRouterRoutesDestinationResponseHeadersOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ConfigEntryServiceRouterRoutesDestinationResponseHeaders | undefined;
    set internalValue(value: ConfigEntryServiceRouterRoutesDestinationResponseHeaders | undefined);
    private _add?;
    get add(): {
        [key: string]: string;
    };
    set add(value: {
        [key: string]: string;
    });
    resetAdd(): void;
    get addInput(): {
        [key: string]: string;
    } | undefined;
    private _remove?;
    get remove(): string[];
    set remove(value: string[]);
    resetRemove(): void;
    get removeInput(): string[] | undefined;
    private _set?;
    get set(): {
        [key: string]: string;
    };
    set set(value: {
        [key: string]: string;
    });
    resetSet(): void;
    get setInput(): {
        [key: string]: string;
    } | undefined;
}
export interface ConfigEntryServiceRouterRoutesDestination {
    /**
    * Specifies the total amount of time permitted for the request stream to be idle.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_router#idle_timeout ConfigEntryServiceRouter#idle_timeout}
    */
    readonly idleTimeout?: string;
    /**
    * Specifies the Consul namespace to resolve the service from instead of the current namespace.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_router#namespace ConfigEntryServiceRouter#namespace}
    */
    readonly namespace?: string;
    /**
    * Specifies the number of times to retry the request when a retry condition occurs.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_router#num_retries ConfigEntryServiceRouter#num_retries}
    */
    readonly numRetries?: number;
    /**
    * Specifies the Consul admin partition to resolve the service from instead of the current partition.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_router#partition ConfigEntryServiceRouter#partition}
    */
    readonly partition?: string;
    /**
    * Specifies rewrites to the HTTP request path before proxying it to its final destination.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_router#prefix_rewrite ConfigEntryServiceRouter#prefix_rewrite}
    */
    readonly prefixRewrite?: string;
    /**
    * Specifies the total amount of time permitted for the entire downstream request to be processed, including retry attempts.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_router#request_timeout ConfigEntryServiceRouter#request_timeout}
    */
    readonly requestTimeout?: string;
    /**
    * Specifies a list of conditions for Consul to retry requests based on the response from an upstream service.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_router#retry_on ConfigEntryServiceRouter#retry_on}
    */
    readonly retryOn?: string[];
    /**
    * Specifies that connection failure errors that trigger a retry request.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_router#retry_on_connect_failure ConfigEntryServiceRouter#retry_on_connect_failure}
    */
    readonly retryOnConnectFailure?: boolean | cdktf.IResolvable;
    /**
    * Specifies a list of integers for HTTP response status codes that trigger a retry request.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_router#retry_on_status_codes ConfigEntryServiceRouter#retry_on_status_codes}
    */
    readonly retryOnStatusCodes?: number[];
    /**
    * Specifies the name of the service to resolve.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_router#service ConfigEntryServiceRouter#service}
    */
    readonly service?: string;
    /**
    * Specifies a named subset of the given service to resolve instead of the one defined as that service's `default_subset` in the service resolver configuration entry.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_router#service_subset ConfigEntryServiceRouter#service_subset}
    */
    readonly serviceSubset?: string;
    /**
    * request_headers block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_router#request_headers ConfigEntryServiceRouter#request_headers}
    */
    readonly requestHeaders?: ConfigEntryServiceRouterRoutesDestinationRequestHeaders;
    /**
    * response_headers block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_router#response_headers ConfigEntryServiceRouter#response_headers}
    */
    readonly responseHeaders?: ConfigEntryServiceRouterRoutesDestinationResponseHeaders;
}
export declare function configEntryServiceRouterRoutesDestinationToTerraform(struct?: ConfigEntryServiceRouterRoutesDestinationOutputReference | ConfigEntryServiceRouterRoutesDestination): any;
export declare function configEntryServiceRouterRoutesDestinationToHclTerraform(struct?: ConfigEntryServiceRouterRoutesDestinationOutputReference | ConfigEntryServiceRouterRoutesDestination): any;
export declare class ConfigEntryServiceRouterRoutesDestinationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ConfigEntryServiceRouterRoutesDestination | undefined;
    set internalValue(value: ConfigEntryServiceRouterRoutesDestination | undefined);
    private _idleTimeout?;
    get idleTimeout(): string;
    set idleTimeout(value: string);
    resetIdleTimeout(): void;
    get idleTimeoutInput(): string | undefined;
    private _namespace?;
    get namespace(): string;
    set namespace(value: string);
    resetNamespace(): void;
    get namespaceInput(): string | undefined;
    private _numRetries?;
    get numRetries(): number;
    set numRetries(value: number);
    resetNumRetries(): void;
    get numRetriesInput(): number | undefined;
    private _partition?;
    get partition(): string;
    set partition(value: string);
    resetPartition(): void;
    get partitionInput(): string | undefined;
    private _prefixRewrite?;
    get prefixRewrite(): string;
    set prefixRewrite(value: string);
    resetPrefixRewrite(): void;
    get prefixRewriteInput(): string | undefined;
    private _requestTimeout?;
    get requestTimeout(): string;
    set requestTimeout(value: string);
    resetRequestTimeout(): void;
    get requestTimeoutInput(): string | undefined;
    private _retryOn?;
    get retryOn(): string[];
    set retryOn(value: string[]);
    resetRetryOn(): void;
    get retryOnInput(): string[] | undefined;
    private _retryOnConnectFailure?;
    get retryOnConnectFailure(): boolean | cdktf.IResolvable;
    set retryOnConnectFailure(value: boolean | cdktf.IResolvable);
    resetRetryOnConnectFailure(): void;
    get retryOnConnectFailureInput(): boolean | cdktf.IResolvable | undefined;
    private _retryOnStatusCodes?;
    get retryOnStatusCodes(): number[];
    set retryOnStatusCodes(value: number[]);
    resetRetryOnStatusCodes(): void;
    get retryOnStatusCodesInput(): number[] | undefined;
    private _service?;
    get service(): string;
    set service(value: string);
    resetService(): void;
    get serviceInput(): string | undefined;
    private _serviceSubset?;
    get serviceSubset(): string;
    set serviceSubset(value: string);
    resetServiceSubset(): void;
    get serviceSubsetInput(): string | undefined;
    private _requestHeaders;
    get requestHeaders(): ConfigEntryServiceRouterRoutesDestinationRequestHeadersOutputReference;
    putRequestHeaders(value: ConfigEntryServiceRouterRoutesDestinationRequestHeaders): void;
    resetRequestHeaders(): void;
    get requestHeadersInput(): ConfigEntryServiceRouterRoutesDestinationRequestHeaders | undefined;
    private _responseHeaders;
    get responseHeaders(): ConfigEntryServiceRouterRoutesDestinationResponseHeadersOutputReference;
    putResponseHeaders(value: ConfigEntryServiceRouterRoutesDestinationResponseHeaders): void;
    resetResponseHeaders(): void;
    get responseHeadersInput(): ConfigEntryServiceRouterRoutesDestinationResponseHeaders | undefined;
}
export interface ConfigEntryServiceRouterRoutesMatchHttpHeader {
    /**
    * Specifies that a request matches when the header with the given name is this exact value.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_router#exact ConfigEntryServiceRouter#exact}
    */
    readonly exact?: string;
    /**
    * Specifies that the logic for the HTTP header match should be inverted.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_router#invert ConfigEntryServiceRouter#invert}
    */
    readonly invert?: boolean | cdktf.IResolvable;
    /**
    * Specifies the name of the HTTP header to match.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_router#name ConfigEntryServiceRouter#name}
    */
    readonly name?: string;
    /**
    * Specifies that a request matches when the header with the given name has this prefix.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_router#prefix ConfigEntryServiceRouter#prefix}
    */
    readonly prefix?: string;
    /**
    * Specifies that a request matches when the value in the `name` argument is present anywhere in the HTTP header.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_router#present ConfigEntryServiceRouter#present}
    */
    readonly present?: boolean | cdktf.IResolvable;
    /**
    * Specifies that a request matches when the header with the given name matches this regular expression.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_router#regex ConfigEntryServiceRouter#regex}
    */
    readonly regex?: string;
    /**
    * Specifies that a request matches when the header with the given name has this suffix.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_router#suffix ConfigEntryServiceRouter#suffix}
    */
    readonly suffix?: string;
}
export declare function configEntryServiceRouterRoutesMatchHttpHeaderToTerraform(struct?: ConfigEntryServiceRouterRoutesMatchHttpHeader | cdktf.IResolvable): any;
export declare function configEntryServiceRouterRoutesMatchHttpHeaderToHclTerraform(struct?: ConfigEntryServiceRouterRoutesMatchHttpHeader | cdktf.IResolvable): any;
export declare class ConfigEntryServiceRouterRoutesMatchHttpHeaderOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ConfigEntryServiceRouterRoutesMatchHttpHeader | cdktf.IResolvable | undefined;
    set internalValue(value: ConfigEntryServiceRouterRoutesMatchHttpHeader | cdktf.IResolvable | undefined);
    private _exact?;
    get exact(): string;
    set exact(value: string);
    resetExact(): void;
    get exactInput(): string | undefined;
    private _invert?;
    get invert(): boolean | cdktf.IResolvable;
    set invert(value: boolean | cdktf.IResolvable);
    resetInvert(): void;
    get invertInput(): boolean | cdktf.IResolvable | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
    private _prefix?;
    get prefix(): string;
    set prefix(value: string);
    resetPrefix(): void;
    get prefixInput(): string | undefined;
    private _present?;
    get present(): boolean | cdktf.IResolvable;
    set present(value: boolean | cdktf.IResolvable);
    resetPresent(): void;
    get presentInput(): boolean | cdktf.IResolvable | undefined;
    private _regex?;
    get regex(): string;
    set regex(value: string);
    resetRegex(): void;
    get regexInput(): string | undefined;
    private _suffix?;
    get suffix(): string;
    set suffix(value: string);
    resetSuffix(): void;
    get suffixInput(): string | undefined;
}
export declare class ConfigEntryServiceRouterRoutesMatchHttpHeaderList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ConfigEntryServiceRouterRoutesMatchHttpHeader[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ConfigEntryServiceRouterRoutesMatchHttpHeaderOutputReference;
}
export interface ConfigEntryServiceRouterRoutesMatchHttpQueryParam {
    /**
    * Specifies that a request matches when the query parameter with the given name is this exact value.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_router#exact ConfigEntryServiceRouter#exact}
    */
    readonly exact?: string;
    /**
    * Specifies the name of the HTTP query parameter to match.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_router#name ConfigEntryServiceRouter#name}
    */
    readonly name?: string;
    /**
    * Specifies that a request matches when the value in the `name` argument is present anywhere in the HTTP query parameter.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_router#present ConfigEntryServiceRouter#present}
    */
    readonly present?: boolean | cdktf.IResolvable;
    /**
    * Specifies that a request matches when the query parameter with the given name matches this regular expression.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_router#regex ConfigEntryServiceRouter#regex}
    */
    readonly regex?: string;
}
export declare function configEntryServiceRouterRoutesMatchHttpQueryParamToTerraform(struct?: ConfigEntryServiceRouterRoutesMatchHttpQueryParam | cdktf.IResolvable): any;
export declare function configEntryServiceRouterRoutesMatchHttpQueryParamToHclTerraform(struct?: ConfigEntryServiceRouterRoutesMatchHttpQueryParam | cdktf.IResolvable): any;
export declare class ConfigEntryServiceRouterRoutesMatchHttpQueryParamOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ConfigEntryServiceRouterRoutesMatchHttpQueryParam | cdktf.IResolvable | undefined;
    set internalValue(value: ConfigEntryServiceRouterRoutesMatchHttpQueryParam | cdktf.IResolvable | undefined);
    private _exact?;
    get exact(): string;
    set exact(value: string);
    resetExact(): void;
    get exactInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
    private _present?;
    get present(): boolean | cdktf.IResolvable;
    set present(value: boolean | cdktf.IResolvable);
    resetPresent(): void;
    get presentInput(): boolean | cdktf.IResolvable | undefined;
    private _regex?;
    get regex(): string;
    set regex(value: string);
    resetRegex(): void;
    get regexInput(): string | undefined;
}
export declare class ConfigEntryServiceRouterRoutesMatchHttpQueryParamList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ConfigEntryServiceRouterRoutesMatchHttpQueryParam[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ConfigEntryServiceRouterRoutesMatchHttpQueryParamOutputReference;
}
export interface ConfigEntryServiceRouterRoutesMatchHttp {
    /**
    * Specifies HTTP methods that the match applies to.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_router#methods ConfigEntryServiceRouter#methods}
    */
    readonly methods?: string[];
    /**
    * Specifies the exact path to match on the HTTP request path.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_router#path_exact ConfigEntryServiceRouter#path_exact}
    */
    readonly pathExact?: string;
    /**
    * Specifies the path prefix to match on the HTTP request path.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_router#path_prefix ConfigEntryServiceRouter#path_prefix}
    */
    readonly pathPrefix?: string;
    /**
    * Specifies a regular expression to match on the HTTP request path.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_router#path_regex ConfigEntryServiceRouter#path_regex}
    */
    readonly pathRegex?: string;
    /**
    * header block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_router#header ConfigEntryServiceRouter#header}
    */
    readonly header?: ConfigEntryServiceRouterRoutesMatchHttpHeader[] | cdktf.IResolvable;
    /**
    * query_param block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_router#query_param ConfigEntryServiceRouter#query_param}
    */
    readonly queryParam?: ConfigEntryServiceRouterRoutesMatchHttpQueryParam[] | cdktf.IResolvable;
}
export declare function configEntryServiceRouterRoutesMatchHttpToTerraform(struct?: ConfigEntryServiceRouterRoutesMatchHttpOutputReference | ConfigEntryServiceRouterRoutesMatchHttp): any;
export declare function configEntryServiceRouterRoutesMatchHttpToHclTerraform(struct?: ConfigEntryServiceRouterRoutesMatchHttpOutputReference | ConfigEntryServiceRouterRoutesMatchHttp): any;
export declare class ConfigEntryServiceRouterRoutesMatchHttpOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ConfigEntryServiceRouterRoutesMatchHttp | undefined;
    set internalValue(value: ConfigEntryServiceRouterRoutesMatchHttp | undefined);
    private _methods?;
    get methods(): string[];
    set methods(value: string[]);
    resetMethods(): void;
    get methodsInput(): string[] | undefined;
    private _pathExact?;
    get pathExact(): string;
    set pathExact(value: string);
    resetPathExact(): void;
    get pathExactInput(): string | undefined;
    private _pathPrefix?;
    get pathPrefix(): string;
    set pathPrefix(value: string);
    resetPathPrefix(): void;
    get pathPrefixInput(): string | undefined;
    private _pathRegex?;
    get pathRegex(): string;
    set pathRegex(value: string);
    resetPathRegex(): void;
    get pathRegexInput(): string | undefined;
    private _header;
    get header(): ConfigEntryServiceRouterRoutesMatchHttpHeaderList;
    putHeader(value: ConfigEntryServiceRouterRoutesMatchHttpHeader[] | cdktf.IResolvable): void;
    resetHeader(): void;
    get headerInput(): cdktf.IResolvable | ConfigEntryServiceRouterRoutesMatchHttpHeader[] | undefined;
    private _queryParam;
    get queryParam(): ConfigEntryServiceRouterRoutesMatchHttpQueryParamList;
    putQueryParam(value: ConfigEntryServiceRouterRoutesMatchHttpQueryParam[] | cdktf.IResolvable): void;
    resetQueryParam(): void;
    get queryParamInput(): cdktf.IResolvable | ConfigEntryServiceRouterRoutesMatchHttpQueryParam[] | undefined;
}
export interface ConfigEntryServiceRouterRoutesMatch {
    /**
    * http block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_router#http ConfigEntryServiceRouter#http}
    */
    readonly http?: ConfigEntryServiceRouterRoutesMatchHttp;
}
export declare function configEntryServiceRouterRoutesMatchToTerraform(struct?: ConfigEntryServiceRouterRoutesMatchOutputReference | ConfigEntryServiceRouterRoutesMatch): any;
export declare function configEntryServiceRouterRoutesMatchToHclTerraform(struct?: ConfigEntryServiceRouterRoutesMatchOutputReference | ConfigEntryServiceRouterRoutesMatch): any;
export declare class ConfigEntryServiceRouterRoutesMatchOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ConfigEntryServiceRouterRoutesMatch | undefined;
    set internalValue(value: ConfigEntryServiceRouterRoutesMatch | undefined);
    private _http;
    get http(): ConfigEntryServiceRouterRoutesMatchHttpOutputReference;
    putHttp(value: ConfigEntryServiceRouterRoutesMatchHttp): void;
    resetHttp(): void;
    get httpInput(): ConfigEntryServiceRouterRoutesMatchHttp | undefined;
}
export interface ConfigEntryServiceRouterRoutes {
    /**
    * destination block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_router#destination ConfigEntryServiceRouter#destination}
    */
    readonly destination?: ConfigEntryServiceRouterRoutesDestination;
    /**
    * match block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_router#match ConfigEntryServiceRouter#match}
    */
    readonly match?: ConfigEntryServiceRouterRoutesMatch;
}
export declare function configEntryServiceRouterRoutesToTerraform(struct?: ConfigEntryServiceRouterRoutes | cdktf.IResolvable): any;
export declare function configEntryServiceRouterRoutesToHclTerraform(struct?: ConfigEntryServiceRouterRoutes | cdktf.IResolvable): any;
export declare class ConfigEntryServiceRouterRoutesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ConfigEntryServiceRouterRoutes | cdktf.IResolvable | undefined;
    set internalValue(value: ConfigEntryServiceRouterRoutes | cdktf.IResolvable | undefined);
    private _destination;
    get destination(): ConfigEntryServiceRouterRoutesDestinationOutputReference;
    putDestination(value: ConfigEntryServiceRouterRoutesDestination): void;
    resetDestination(): void;
    get destinationInput(): ConfigEntryServiceRouterRoutesDestination | undefined;
    private _match;
    get match(): ConfigEntryServiceRouterRoutesMatchOutputReference;
    putMatch(value: ConfigEntryServiceRouterRoutesMatch): void;
    resetMatch(): void;
    get matchInput(): ConfigEntryServiceRouterRoutesMatch | undefined;
}
export declare class ConfigEntryServiceRouterRoutesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ConfigEntryServiceRouterRoutes[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ConfigEntryServiceRouterRoutesOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_router consul_config_entry_service_router}
*/
export declare class ConfigEntryServiceRouter extends cdktf.TerraformResource {
    static readonly tfResourceType = "consul_config_entry_service_router";
    /**
    * Generates CDKTF code for importing a ConfigEntryServiceRouter resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the ConfigEntryServiceRouter to import
    * @param importFromId The id of the existing ConfigEntryServiceRouter that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_router#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the ConfigEntryServiceRouter to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_router consul_config_entry_service_router} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options ConfigEntryServiceRouterConfig
    */
    constructor(scope: Construct, id: string, config: ConfigEntryServiceRouterConfig);
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _meta?;
    get meta(): {
        [key: string]: string;
    };
    set meta(value: {
        [key: string]: string;
    });
    resetMeta(): void;
    get metaInput(): {
        [key: string]: string;
    } | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _namespace?;
    get namespace(): string;
    set namespace(value: string);
    resetNamespace(): void;
    get namespaceInput(): string | undefined;
    private _partition?;
    get partition(): string;
    set partition(value: string);
    resetPartition(): void;
    get partitionInput(): string | undefined;
    private _routes;
    get routes(): ConfigEntryServiceRouterRoutesList;
    putRoutes(value: ConfigEntryServiceRouterRoutes[] | cdktf.IResolvable): void;
    resetRoutes(): void;
    get routesInput(): cdktf.IResolvable | ConfigEntryServiceRouterRoutes[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
