/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface ConfigEntryServiceSplitterConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_splitter#id ConfigEntryServiceSplitter#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Specifies key-value pairs to add to the KV store.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_splitter#meta ConfigEntryServiceSplitter#meta}
    */
    readonly meta?: {
        [key: string]: string;
    };
    /**
    * Specifies a name for the configuration entry.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_splitter#name ConfigEntryServiceSplitter#name}
    */
    readonly name: string;
    /**
    * Specifies the namespace to apply the configuration entry.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_splitter#namespace ConfigEntryServiceSplitter#namespace}
    */
    readonly namespace?: string;
    /**
    * Specifies the admin partition to apply the configuration entry.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_splitter#partition ConfigEntryServiceSplitter#partition}
    */
    readonly partition?: string;
    /**
    * splits block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_splitter#splits ConfigEntryServiceSplitter#splits}
    */
    readonly splits: ConfigEntryServiceSplitterSplits[] | cdktf.IResolvable;
}
export interface ConfigEntryServiceSplitterSplitsRequestHeaders {
    /**
    * Map of one or more key-value pairs. Defines a set of key-value pairs to add to the header. Use header names as the keys. Header names are not case-sensitive. If header values with the same name already exist, the value is appended and Consul applies both headers.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_splitter#add ConfigEntryServiceSplitter#add}
    */
    readonly add?: {
        [key: string]: string;
    };
    /**
    * Defines an list of headers to remove. Consul removes only headers containing exact matches. Header names are not case-sensitive.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_splitter#remove ConfigEntryServiceSplitter#remove}
    */
    readonly remove?: string[];
    /**
    * Map of one or more key-value pairs. Defines a set of key-value pairs to add to the request header or to replace existing header values with. Use header names as the keys. Header names are not case-sensitive. If header values with the same names already exist, Consul replaces the header values.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_splitter#set ConfigEntryServiceSplitter#set}
    */
    readonly set?: {
        [key: string]: string;
    };
}
export declare function configEntryServiceSplitterSplitsRequestHeadersToTerraform(struct?: ConfigEntryServiceSplitterSplitsRequestHeadersOutputReference | ConfigEntryServiceSplitterSplitsRequestHeaders): any;
export declare function configEntryServiceSplitterSplitsRequestHeadersToHclTerraform(struct?: ConfigEntryServiceSplitterSplitsRequestHeadersOutputReference | ConfigEntryServiceSplitterSplitsRequestHeaders): any;
export declare class ConfigEntryServiceSplitterSplitsRequestHeadersOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ConfigEntryServiceSplitterSplitsRequestHeaders | undefined;
    set internalValue(value: ConfigEntryServiceSplitterSplitsRequestHeaders | undefined);
    private _add?;
    get add(): {
        [key: string]: string;
    };
    set add(value: {
        [key: string]: string;
    });
    resetAdd(): void;
    get addInput(): {
        [key: string]: string;
    } | undefined;
    private _remove?;
    get remove(): string[];
    set remove(value: string[]);
    resetRemove(): void;
    get removeInput(): string[] | undefined;
    private _set?;
    get set(): {
        [key: string]: string;
    };
    set set(value: {
        [key: string]: string;
    });
    resetSet(): void;
    get setInput(): {
        [key: string]: string;
    } | undefined;
}
export interface ConfigEntryServiceSplitterSplitsResponseHeaders {
    /**
    * Map of one or more key-value pairs. Defines a set of key-value pairs to add to the header. Use header names as the keys. Header names are not case-sensitive. If header values with the same name already exist, the value is appended and Consul applies both headers.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_splitter#add ConfigEntryServiceSplitter#add}
    */
    readonly add?: {
        [key: string]: string;
    };
    /**
    * Defines an list of headers to remove. Consul removes only headers containing exact matches. Header names are not case-sensitive.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_splitter#remove ConfigEntryServiceSplitter#remove}
    */
    readonly remove?: string[];
    /**
    * Map of one or more key-value pairs. Defines a set of key-value pairs to add to the request header or to replace existing header values with. Use header names as the keys. Header names are not case-sensitive. If header values with the same names already exist, Consul replaces the header values.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_splitter#set ConfigEntryServiceSplitter#set}
    */
    readonly set?: {
        [key: string]: string;
    };
}
export declare function configEntryServiceSplitterSplitsResponseHeadersToTerraform(struct?: ConfigEntryServiceSplitterSplitsResponseHeadersOutputReference | ConfigEntryServiceSplitterSplitsResponseHeaders): any;
export declare function configEntryServiceSplitterSplitsResponseHeadersToHclTerraform(struct?: ConfigEntryServiceSplitterSplitsResponseHeadersOutputReference | ConfigEntryServiceSplitterSplitsResponseHeaders): any;
export declare class ConfigEntryServiceSplitterSplitsResponseHeadersOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ConfigEntryServiceSplitterSplitsResponseHeaders | undefined;
    set internalValue(value: ConfigEntryServiceSplitterSplitsResponseHeaders | undefined);
    private _add?;
    get add(): {
        [key: string]: string;
    };
    set add(value: {
        [key: string]: string;
    });
    resetAdd(): void;
    get addInput(): {
        [key: string]: string;
    } | undefined;
    private _remove?;
    get remove(): string[];
    set remove(value: string[]);
    resetRemove(): void;
    get removeInput(): string[] | undefined;
    private _set?;
    get set(): {
        [key: string]: string;
    };
    set set(value: {
        [key: string]: string;
    });
    resetSet(): void;
    get setInput(): {
        [key: string]: string;
    } | undefined;
}
export interface ConfigEntryServiceSplitterSplits {
    /**
    * Specifies the namespace to use in the FQDN when resolving the service.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_splitter#namespace ConfigEntryServiceSplitter#namespace}
    */
    readonly namespace?: string;
    /**
    * Specifies the admin partition to use in the FQDN when resolving the service.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_splitter#partition ConfigEntryServiceSplitter#partition}
    */
    readonly partition?: string;
    /**
    * Specifies the name of the service to resolve.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_splitter#service ConfigEntryServiceSplitter#service}
    */
    readonly service: string;
    /**
    * Specifies a subset of the service to resolve. A service subset assigns a name to a specific subset of discoverable service instances within a datacenter, such as `version2` or `canary`. All services have an unnamed default subset that returns all healthy instances.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_splitter#service_subset ConfigEntryServiceSplitter#service_subset}
    */
    readonly serviceSubset?: string;
    /**
    * Specifies the percentage of traffic sent to the set of service instances specified in the `service` field. Each weight must be a floating integer between `0` and `100`. The smallest representable value is `.01`. The sum of weights across all splits must add up to `100`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_splitter#weight ConfigEntryServiceSplitter#weight}
    */
    readonly weight: number;
    /**
    * request_headers block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_splitter#request_headers ConfigEntryServiceSplitter#request_headers}
    */
    readonly requestHeaders?: ConfigEntryServiceSplitterSplitsRequestHeaders;
    /**
    * response_headers block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_splitter#response_headers ConfigEntryServiceSplitter#response_headers}
    */
    readonly responseHeaders?: ConfigEntryServiceSplitterSplitsResponseHeaders;
}
export declare function configEntryServiceSplitterSplitsToTerraform(struct?: ConfigEntryServiceSplitterSplits | cdktf.IResolvable): any;
export declare function configEntryServiceSplitterSplitsToHclTerraform(struct?: ConfigEntryServiceSplitterSplits | cdktf.IResolvable): any;
export declare class ConfigEntryServiceSplitterSplitsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ConfigEntryServiceSplitterSplits | cdktf.IResolvable | undefined;
    set internalValue(value: ConfigEntryServiceSplitterSplits | cdktf.IResolvable | undefined);
    private _namespace?;
    get namespace(): string;
    set namespace(value: string);
    resetNamespace(): void;
    get namespaceInput(): string | undefined;
    private _partition?;
    get partition(): string;
    set partition(value: string);
    resetPartition(): void;
    get partitionInput(): string | undefined;
    private _service?;
    get service(): string;
    set service(value: string);
    get serviceInput(): string | undefined;
    private _serviceSubset?;
    get serviceSubset(): string;
    set serviceSubset(value: string);
    resetServiceSubset(): void;
    get serviceSubsetInput(): string | undefined;
    private _weight?;
    get weight(): number;
    set weight(value: number);
    get weightInput(): number | undefined;
    private _requestHeaders;
    get requestHeaders(): ConfigEntryServiceSplitterSplitsRequestHeadersOutputReference;
    putRequestHeaders(value: ConfigEntryServiceSplitterSplitsRequestHeaders): void;
    resetRequestHeaders(): void;
    get requestHeadersInput(): ConfigEntryServiceSplitterSplitsRequestHeaders | undefined;
    private _responseHeaders;
    get responseHeaders(): ConfigEntryServiceSplitterSplitsResponseHeadersOutputReference;
    putResponseHeaders(value: ConfigEntryServiceSplitterSplitsResponseHeaders): void;
    resetResponseHeaders(): void;
    get responseHeadersInput(): ConfigEntryServiceSplitterSplitsResponseHeaders | undefined;
}
export declare class ConfigEntryServiceSplitterSplitsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ConfigEntryServiceSplitterSplits[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ConfigEntryServiceSplitterSplitsOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_splitter consul_config_entry_service_splitter}
*/
export declare class ConfigEntryServiceSplitter extends cdktf.TerraformResource {
    static readonly tfResourceType = "consul_config_entry_service_splitter";
    /**
    * Generates CDKTF code for importing a ConfigEntryServiceSplitter resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the ConfigEntryServiceSplitter to import
    * @param importFromId The id of the existing ConfigEntryServiceSplitter that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_splitter#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the ConfigEntryServiceSplitter to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_service_splitter consul_config_entry_service_splitter} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options ConfigEntryServiceSplitterConfig
    */
    constructor(scope: Construct, id: string, config: ConfigEntryServiceSplitterConfig);
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _meta?;
    get meta(): {
        [key: string]: string;
    };
    set meta(value: {
        [key: string]: string;
    });
    resetMeta(): void;
    get metaInput(): {
        [key: string]: string;
    } | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _namespace?;
    get namespace(): string;
    set namespace(value: string);
    resetNamespace(): void;
    get namespaceInput(): string | undefined;
    private _partition?;
    get partition(): string;
    set partition(value: string);
    resetPartition(): void;
    get partitionInput(): string | undefined;
    private _splits;
    get splits(): ConfigEntryServiceSplitterSplitsList;
    putSplits(value: ConfigEntryServiceSplitterSplits[] | cdktf.IResolvable): void;
    get splitsInput(): cdktf.IResolvable | ConfigEntryServiceSplitterSplits[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
