/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface ConfigEntryV2ExportedServicesConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_v2_exported_services#id ConfigEntryV2ExportedServices#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The kind of exported services config (ExportedServices, NamespaceExportedServices, PartitionExportedServices).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_v2_exported_services#kind ConfigEntryV2ExportedServices#kind}
    */
    readonly kind: string;
    /**
    * The name of the config entry to read.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_v2_exported_services#name ConfigEntryV2ExportedServices#name}
    */
    readonly name: string;
    /**
    * The namespace the config entry is associated with.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_v2_exported_services#namespace ConfigEntryV2ExportedServices#namespace}
    */
    readonly namespace?: string;
    /**
    * The partition the config entry is associated with.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_v2_exported_services#partition ConfigEntryV2ExportedServices#partition}
    */
    readonly partition: string;
    /**
    * The exported service partition consumers.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_v2_exported_services#partition_consumers ConfigEntryV2ExportedServices#partition_consumers}
    */
    readonly partitionConsumers?: string[];
    /**
    * The exported service peer consumers.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_v2_exported_services#peer_consumers ConfigEntryV2ExportedServices#peer_consumers}
    */
    readonly peerConsumers?: string[];
    /**
    * The exported service sameness group consumers.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_v2_exported_services#sameness_group_consumers ConfigEntryV2ExportedServices#sameness_group_consumers}
    */
    readonly samenessGroupConsumers?: string[];
    /**
    * The exported services.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_v2_exported_services#services ConfigEntryV2ExportedServices#services}
    */
    readonly services?: string[];
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_v2_exported_services consul_config_entry_v2_exported_services}
*/
export declare class ConfigEntryV2ExportedServices extends cdktf.TerraformResource {
    static readonly tfResourceType = "consul_config_entry_v2_exported_services";
    /**
    * Generates CDKTF code for importing a ConfigEntryV2ExportedServices resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the ConfigEntryV2ExportedServices to import
    * @param importFromId The id of the existing ConfigEntryV2ExportedServices that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_v2_exported_services#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the ConfigEntryV2ExportedServices to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/config_entry_v2_exported_services consul_config_entry_v2_exported_services} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options ConfigEntryV2ExportedServicesConfig
    */
    constructor(scope: Construct, id: string, config: ConfigEntryV2ExportedServicesConfig);
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _kind?;
    get kind(): string;
    set kind(value: string);
    get kindInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _namespace?;
    get namespace(): string;
    set namespace(value: string);
    resetNamespace(): void;
    get namespaceInput(): string | undefined;
    private _partition?;
    get partition(): string;
    set partition(value: string);
    get partitionInput(): string | undefined;
    private _partitionConsumers?;
    get partitionConsumers(): string[];
    set partitionConsumers(value: string[]);
    resetPartitionConsumers(): void;
    get partitionConsumersInput(): string[] | undefined;
    private _peerConsumers?;
    get peerConsumers(): string[];
    set peerConsumers(value: string[]);
    resetPeerConsumers(): void;
    get peerConsumersInput(): string[] | undefined;
    private _samenessGroupConsumers?;
    get samenessGroupConsumers(): string[];
    set samenessGroupConsumers(value: string[]);
    resetSamenessGroupConsumers(): void;
    get samenessGroupConsumersInput(): string[] | undefined;
    private _services?;
    get services(): string[];
    set services(value: string[]);
    resetServices(): void;
    get servicesInput(): string[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
