/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataConsulKeysConfig extends cdktf.TerraformMetaArguments {
    /**
    * The datacenter to use. This overrides the agent's default datacenter and the datacenter in the provider setup.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/data-sources/keys#datacenter DataConsulKeys#datacenter}
    */
    readonly datacenter?: string;
    /**
    * Whether to return an error when a key is absent from the KV store and no default is configured. This defaults to `false`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/data-sources/keys#error_on_missing_keys DataConsulKeys#error_on_missing_keys}
    */
    readonly errorOnMissingKeys?: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/data-sources/keys#id DataConsulKeys#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The namespace to lookup the keys.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/data-sources/keys#namespace DataConsulKeys#namespace}
    */
    readonly namespace?: string;
    /**
    * The partition to lookup the keys.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/data-sources/keys#partition DataConsulKeys#partition}
    */
    readonly partition?: string;
    /**
    * The ACL token to use. This overrides the token that the agent provides by default.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/data-sources/keys#token DataConsulKeys#token}
    */
    readonly token?: string;
    /**
    * key block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/data-sources/keys#key DataConsulKeys#key}
    */
    readonly key?: DataConsulKeysKey[] | cdktf.IResolvable;
}
export interface DataConsulKeysKey {
    /**
    * This is the default value to set for `var.<name>` if the key does not exist in Consul. Defaults to an empty string.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/data-sources/keys#default DataConsulKeys#default}
    */
    readonly default?: string;
    /**
    * This is the name of the key. This value of the key is exposed as `var.<name>`. This is not the path of the key in Consul.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/data-sources/keys#name DataConsulKeys#name}
    */
    readonly name: string;
    /**
    * This is the path in Consul that should be read or written to.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/data-sources/keys#path DataConsulKeys#path}
    */
    readonly path: string;
}
export declare function dataConsulKeysKeyToTerraform(struct?: DataConsulKeysKey | cdktf.IResolvable): any;
export declare function dataConsulKeysKeyToHclTerraform(struct?: DataConsulKeysKey | cdktf.IResolvable): any;
export declare class DataConsulKeysKeyOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataConsulKeysKey | cdktf.IResolvable | undefined;
    set internalValue(value: DataConsulKeysKey | cdktf.IResolvable | undefined);
    private _default?;
    get default(): string;
    set default(value: string);
    resetDefault(): void;
    get defaultInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _path?;
    get path(): string;
    set path(value: string);
    get pathInput(): string | undefined;
}
export declare class DataConsulKeysKeyList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: DataConsulKeysKey[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataConsulKeysKeyOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/data-sources/keys consul_keys}
*/
export declare class DataConsulKeys extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "consul_keys";
    /**
    * Generates CDKTF code for importing a DataConsulKeys resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the DataConsulKeys to import
    * @param importFromId The id of the existing DataConsulKeys that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/data-sources/keys#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the DataConsulKeys to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/data-sources/keys consul_keys} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataConsulKeysConfig = {}
    */
    constructor(scope: Construct, id: string, config?: DataConsulKeysConfig);
    private _datacenter?;
    get datacenter(): string;
    set datacenter(value: string);
    resetDatacenter(): void;
    get datacenterInput(): string | undefined;
    private _errorOnMissingKeys?;
    get errorOnMissingKeys(): boolean | cdktf.IResolvable;
    set errorOnMissingKeys(value: boolean | cdktf.IResolvable);
    resetErrorOnMissingKeys(): void;
    get errorOnMissingKeysInput(): boolean | cdktf.IResolvable | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _namespace?;
    get namespace(): string;
    set namespace(value: string);
    resetNamespace(): void;
    get namespaceInput(): string | undefined;
    private _partition?;
    get partition(): string;
    set partition(value: string);
    resetPartition(): void;
    get partitionInput(): string | undefined;
    private _token?;
    get token(): string;
    set token(value: string);
    resetToken(): void;
    get tokenInput(): string | undefined;
    private _var;
    get var(): cdktf.StringMap;
    private _key;
    get key(): DataConsulKeysKeyList;
    putKey(value: DataConsulKeysKey[] | cdktf.IResolvable): void;
    resetKey(): void;
    get keyInput(): cdktf.IResolvable | DataConsulKeysKey[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
