/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataConsulNodesConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/data-sources/nodes#id DataConsulNodes#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * query_options block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/data-sources/nodes#query_options DataConsulNodes#query_options}
    */
    readonly queryOptions?: DataConsulNodesQueryOptions[] | cdktf.IResolvable;
}
export interface DataConsulNodesNodes {
}
export declare function dataConsulNodesNodesToTerraform(struct?: DataConsulNodesNodes): any;
export declare function dataConsulNodesNodesToHclTerraform(struct?: DataConsulNodesNodes): any;
export declare class DataConsulNodesNodesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataConsulNodesNodes | undefined;
    set internalValue(value: DataConsulNodesNodes | undefined);
    get address(): string;
    get id(): string;
    private _meta;
    get meta(): cdktf.StringMap;
    get name(): string;
    private _taggedAddresses;
    get taggedAddresses(): cdktf.StringMap;
}
export declare class DataConsulNodesNodesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataConsulNodesNodesOutputReference;
}
export interface DataConsulNodesQueryOptions {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/data-sources/nodes#allow_stale DataConsulNodes#allow_stale}
    */
    readonly allowStale?: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/data-sources/nodes#datacenter DataConsulNodes#datacenter}
    */
    readonly datacenter?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/data-sources/nodes#near DataConsulNodes#near}
    */
    readonly near?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/data-sources/nodes#node_meta DataConsulNodes#node_meta}
    */
    readonly nodeMeta?: {
        [key: string]: string;
    };
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/data-sources/nodes#partition DataConsulNodes#partition}
    */
    readonly partition?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/data-sources/nodes#require_consistent DataConsulNodes#require_consistent}
    */
    readonly requireConsistent?: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/data-sources/nodes#token DataConsulNodes#token}
    */
    readonly token?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/data-sources/nodes#wait_index DataConsulNodes#wait_index}
    */
    readonly waitIndex?: number;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/data-sources/nodes#wait_time DataConsulNodes#wait_time}
    */
    readonly waitTime?: string;
}
export declare function dataConsulNodesQueryOptionsToTerraform(struct?: DataConsulNodesQueryOptions | cdktf.IResolvable): any;
export declare function dataConsulNodesQueryOptionsToHclTerraform(struct?: DataConsulNodesQueryOptions | cdktf.IResolvable): any;
export declare class DataConsulNodesQueryOptionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataConsulNodesQueryOptions | cdktf.IResolvable | undefined;
    set internalValue(value: DataConsulNodesQueryOptions | cdktf.IResolvable | undefined);
    private _allowStale?;
    get allowStale(): boolean | cdktf.IResolvable;
    set allowStale(value: boolean | cdktf.IResolvable);
    resetAllowStale(): void;
    get allowStaleInput(): boolean | cdktf.IResolvable | undefined;
    private _datacenter?;
    get datacenter(): string;
    set datacenter(value: string);
    resetDatacenter(): void;
    get datacenterInput(): string | undefined;
    private _near?;
    get near(): string;
    set near(value: string);
    resetNear(): void;
    get nearInput(): string | undefined;
    private _nodeMeta?;
    get nodeMeta(): {
        [key: string]: string;
    };
    set nodeMeta(value: {
        [key: string]: string;
    });
    resetNodeMeta(): void;
    get nodeMetaInput(): {
        [key: string]: string;
    } | undefined;
    private _partition?;
    get partition(): string;
    set partition(value: string);
    resetPartition(): void;
    get partitionInput(): string | undefined;
    private _requireConsistent?;
    get requireConsistent(): boolean | cdktf.IResolvable;
    set requireConsistent(value: boolean | cdktf.IResolvable);
    resetRequireConsistent(): void;
    get requireConsistentInput(): boolean | cdktf.IResolvable | undefined;
    private _token?;
    get token(): string;
    set token(value: string);
    resetToken(): void;
    get tokenInput(): string | undefined;
    private _waitIndex?;
    get waitIndex(): number;
    set waitIndex(value: number);
    resetWaitIndex(): void;
    get waitIndexInput(): number | undefined;
    private _waitTime?;
    get waitTime(): string;
    set waitTime(value: string);
    resetWaitTime(): void;
    get waitTimeInput(): string | undefined;
}
export declare class DataConsulNodesQueryOptionsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: DataConsulNodesQueryOptions[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataConsulNodesQueryOptionsOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/data-sources/nodes consul_nodes}
*/
export declare class DataConsulNodes extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "consul_nodes";
    /**
    * Generates CDKTF code for importing a DataConsulNodes resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the DataConsulNodes to import
    * @param importFromId The id of the existing DataConsulNodes that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/data-sources/nodes#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the DataConsulNodes to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/data-sources/nodes consul_nodes} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataConsulNodesConfig = {}
    */
    constructor(scope: Construct, id: string, config?: DataConsulNodesConfig);
    get datacenter(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get nodeIds(): string[];
    get nodeNames(): string[];
    private _nodes;
    get nodes(): DataConsulNodesNodesList;
    private _queryOptions;
    get queryOptions(): DataConsulNodesQueryOptionsList;
    putQueryOptions(value: DataConsulNodesQueryOptions[] | cdktf.IResolvable): void;
    resetQueryOptions(): void;
    get queryOptionsInput(): cdktf.IResolvable | DataConsulNodesQueryOptions[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
