/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataConsulServicesConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/data-sources/services#id DataConsulServices#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * query_options block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/data-sources/services#query_options DataConsulServices#query_options}
    */
    readonly queryOptions?: DataConsulServicesQueryOptions[] | cdktf.IResolvable;
}
export interface DataConsulServicesQueryOptions {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/data-sources/services#allow_stale DataConsulServices#allow_stale}
    */
    readonly allowStale?: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/data-sources/services#datacenter DataConsulServices#datacenter}
    */
    readonly datacenter?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/data-sources/services#namespace DataConsulServices#namespace}
    */
    readonly namespace?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/data-sources/services#near DataConsulServices#near}
    */
    readonly near?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/data-sources/services#node_meta DataConsulServices#node_meta}
    */
    readonly nodeMeta?: {
        [key: string]: string;
    };
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/data-sources/services#partition DataConsulServices#partition}
    */
    readonly partition?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/data-sources/services#require_consistent DataConsulServices#require_consistent}
    */
    readonly requireConsistent?: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/data-sources/services#token DataConsulServices#token}
    */
    readonly token?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/data-sources/services#wait_index DataConsulServices#wait_index}
    */
    readonly waitIndex?: number;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/data-sources/services#wait_time DataConsulServices#wait_time}
    */
    readonly waitTime?: string;
}
export declare function dataConsulServicesQueryOptionsToTerraform(struct?: DataConsulServicesQueryOptions | cdktf.IResolvable): any;
export declare function dataConsulServicesQueryOptionsToHclTerraform(struct?: DataConsulServicesQueryOptions | cdktf.IResolvable): any;
export declare class DataConsulServicesQueryOptionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataConsulServicesQueryOptions | cdktf.IResolvable | undefined;
    set internalValue(value: DataConsulServicesQueryOptions | cdktf.IResolvable | undefined);
    private _allowStale?;
    get allowStale(): boolean | cdktf.IResolvable;
    set allowStale(value: boolean | cdktf.IResolvable);
    resetAllowStale(): void;
    get allowStaleInput(): boolean | cdktf.IResolvable | undefined;
    private _datacenter?;
    get datacenter(): string;
    set datacenter(value: string);
    resetDatacenter(): void;
    get datacenterInput(): string | undefined;
    private _namespace?;
    get namespace(): string;
    set namespace(value: string);
    resetNamespace(): void;
    get namespaceInput(): string | undefined;
    private _near?;
    get near(): string;
    set near(value: string);
    resetNear(): void;
    get nearInput(): string | undefined;
    private _nodeMeta?;
    get nodeMeta(): {
        [key: string]: string;
    };
    set nodeMeta(value: {
        [key: string]: string;
    });
    resetNodeMeta(): void;
    get nodeMetaInput(): {
        [key: string]: string;
    } | undefined;
    private _partition?;
    get partition(): string;
    set partition(value: string);
    resetPartition(): void;
    get partitionInput(): string | undefined;
    private _requireConsistent?;
    get requireConsistent(): boolean | cdktf.IResolvable;
    set requireConsistent(value: boolean | cdktf.IResolvable);
    resetRequireConsistent(): void;
    get requireConsistentInput(): boolean | cdktf.IResolvable | undefined;
    private _token?;
    get token(): string;
    set token(value: string);
    resetToken(): void;
    get tokenInput(): string | undefined;
    private _waitIndex?;
    get waitIndex(): number;
    set waitIndex(value: number);
    resetWaitIndex(): void;
    get waitIndexInput(): number | undefined;
    private _waitTime?;
    get waitTime(): string;
    set waitTime(value: string);
    resetWaitTime(): void;
    get waitTimeInput(): string | undefined;
}
export declare class DataConsulServicesQueryOptionsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: DataConsulServicesQueryOptions[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataConsulServicesQueryOptionsOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/data-sources/services consul_services}
*/
export declare class DataConsulServices extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "consul_services";
    /**
    * Generates CDKTF code for importing a DataConsulServices resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the DataConsulServices to import
    * @param importFromId The id of the existing DataConsulServices that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/data-sources/services#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the DataConsulServices to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/data-sources/services consul_services} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataConsulServicesConfig = {}
    */
    constructor(scope: Construct, id: string, config?: DataConsulServicesConfig);
    get datacenter(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get names(): string[];
    private _services;
    get services(): cdktf.StringMap;
    private _tags;
    get tags(): cdktf.StringMap;
    private _queryOptions;
    get queryOptions(): DataConsulServicesQueryOptionsList;
    putQueryOptions(value: DataConsulServicesQueryOptions[] | cdktf.IResolvable): void;
    resetQueryOptions(): void;
    get queryOptionsInput(): cdktf.IResolvable | DataConsulServicesQueryOptions[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
