/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface PreparedQueryConfig extends cdktf.TerraformMetaArguments {
    /**
    * When `true` the prepared query will return connect proxy services for a queried service.  Conditions such as `tags` in the prepared query will be matched against the proxy service. Defaults to false.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/prepared_query#connect PreparedQuery#connect}
    */
    readonly connect?: boolean | cdktf.IResolvable;
    /**
    * The datacenter to use. This overrides the agent's default datacenter and the datacenter in the provider setup.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/prepared_query#datacenter PreparedQuery#datacenter}
    */
    readonly datacenter?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/prepared_query#id PreparedQuery#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Specifies a list of check IDs that should be ignored when filtering unhealthy instances. This is mostly useful in an emergency or as a temporary measure when a health check is found to be unreliable. Being able to ignore it in centrally-defined queries can be simpler than de-registering the check as an interim solution until the check can be fixed.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/prepared_query#ignore_check_ids PreparedQuery#ignore_check_ids}
    */
    readonly ignoreCheckIds?: string[];
    /**
    * The name of the prepared query. Used to identify the prepared query during requests. Can be specified as an empty string to configure the query as a catch-all.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/prepared_query#name PreparedQuery#name}
    */
    readonly name: string;
    /**
    * Allows specifying the name of a node to sort results near using Consul's distance sorting and network coordinates. The magic `_agent` value can be used to always sort nearest the node servicing the request.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/prepared_query#near PreparedQuery#near}
    */
    readonly near?: string;
    /**
    * Specifies a list of user-defined key/value pairs that will be used for filtering the query results to nodes with the given metadata values present.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/prepared_query#node_meta PreparedQuery#node_meta}
    */
    readonly nodeMeta?: {
        [key: string]: string;
    };
    /**
    * When `true`, the prepared query will only return nodes with passing health checks in the result.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/prepared_query#only_passing PreparedQuery#only_passing}
    */
    readonly onlyPassing?: boolean | cdktf.IResolvable;
    /**
    * The name of the service to query
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/prepared_query#service PreparedQuery#service}
    */
    readonly service: string;
    /**
    * Specifies a list of user-defined key/value pairs that will be used for filtering the query results to services with the given metadata values present.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/prepared_query#service_meta PreparedQuery#service_meta}
    */
    readonly serviceMeta?: {
        [key: string]: string;
    };
    /**
    * The name of the Consul session to tie this query's lifetime to.  This is an advanced parameter that should not be used without a complete understanding of Consul sessions and the implications of their use (it is recommended to leave this blank in nearly all cases).  If this parameter is omitted the query will not expire.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/prepared_query#session PreparedQuery#session}
    */
    readonly session?: string;
    /**
    * The ACL token to store with the prepared query. This token will be used by default whenever the query is executed.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/prepared_query#stored_token PreparedQuery#stored_token}
    */
    readonly storedToken?: string;
    /**
    * The list of required and/or disallowed tags.  If a tag is in this list it must be present.  If the tag is preceded with a "!" then it is disallowed.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/prepared_query#tags PreparedQuery#tags}
    */
    readonly tags?: string[];
    /**
    * The ACL token to use when saving the prepared query. This overrides the token that the agent provides by default.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/prepared_query#token PreparedQuery#token}
    */
    readonly token?: string;
    /**
    * dns block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/prepared_query#dns PreparedQuery#dns}
    */
    readonly dns?: PreparedQueryDns;
    /**
    * failover block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/prepared_query#failover PreparedQuery#failover}
    */
    readonly failover?: PreparedQueryFailover;
    /**
    * template block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/prepared_query#template PreparedQuery#template}
    */
    readonly template?: PreparedQueryTemplate;
}
export interface PreparedQueryDns {
    /**
    * The TTL to send when returning DNS results.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/prepared_query#ttl PreparedQuery#ttl}
    */
    readonly ttl?: string;
}
export declare function preparedQueryDnsToTerraform(struct?: PreparedQueryDnsOutputReference | PreparedQueryDns): any;
export declare function preparedQueryDnsToHclTerraform(struct?: PreparedQueryDnsOutputReference | PreparedQueryDns): any;
export declare class PreparedQueryDnsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): PreparedQueryDns | undefined;
    set internalValue(value: PreparedQueryDns | undefined);
    private _ttl?;
    get ttl(): string;
    set ttl(value: string);
    resetTtl(): void;
    get ttlInput(): string | undefined;
}
export interface PreparedQueryFailoverTargets {
    /**
    * Specifies a WAN federated datacenter to forward the query to.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/prepared_query#datacenter PreparedQuery#datacenter}
    */
    readonly datacenter?: string;
    /**
    * Specifies a cluster peer to use for failover.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/prepared_query#peer PreparedQuery#peer}
    */
    readonly peer?: string;
}
export declare function preparedQueryFailoverTargetsToTerraform(struct?: PreparedQueryFailoverTargets | cdktf.IResolvable): any;
export declare function preparedQueryFailoverTargetsToHclTerraform(struct?: PreparedQueryFailoverTargets | cdktf.IResolvable): any;
export declare class PreparedQueryFailoverTargetsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): PreparedQueryFailoverTargets | cdktf.IResolvable | undefined;
    set internalValue(value: PreparedQueryFailoverTargets | cdktf.IResolvable | undefined);
    private _datacenter?;
    get datacenter(): string;
    set datacenter(value: string);
    resetDatacenter(): void;
    get datacenterInput(): string | undefined;
    private _peer?;
    get peer(): string;
    set peer(value: string);
    resetPeer(): void;
    get peerInput(): string | undefined;
}
export declare class PreparedQueryFailoverTargetsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: PreparedQueryFailoverTargets[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): PreparedQueryFailoverTargetsOutputReference;
}
export interface PreparedQueryFailover {
    /**
    * Remote datacenters to return results from.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/prepared_query#datacenters PreparedQuery#datacenters}
    */
    readonly datacenters?: string[];
    /**
    * Return results from this many datacenters, sorted in ascending order of estimated RTT.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/prepared_query#nearest_n PreparedQuery#nearest_n}
    */
    readonly nearestN?: number;
    /**
    * targets block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/prepared_query#targets PreparedQuery#targets}
    */
    readonly targets?: PreparedQueryFailoverTargets[] | cdktf.IResolvable;
}
export declare function preparedQueryFailoverToTerraform(struct?: PreparedQueryFailoverOutputReference | PreparedQueryFailover): any;
export declare function preparedQueryFailoverToHclTerraform(struct?: PreparedQueryFailoverOutputReference | PreparedQueryFailover): any;
export declare class PreparedQueryFailoverOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): PreparedQueryFailover | undefined;
    set internalValue(value: PreparedQueryFailover | undefined);
    private _datacenters?;
    get datacenters(): string[];
    set datacenters(value: string[]);
    resetDatacenters(): void;
    get datacentersInput(): string[] | undefined;
    private _nearestN?;
    get nearestN(): number;
    set nearestN(value: number);
    resetNearestN(): void;
    get nearestNInput(): number | undefined;
    private _targets;
    get targets(): PreparedQueryFailoverTargetsList;
    putTargets(value: PreparedQueryFailoverTargets[] | cdktf.IResolvable): void;
    resetTargets(): void;
    get targetsInput(): cdktf.IResolvable | PreparedQueryFailoverTargets[] | undefined;
}
export interface PreparedQueryTemplate {
    /**
    * The regular expression to match with. When using `name_prefix_match`, this regex is applied against the query name.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/prepared_query#regexp PreparedQuery#regexp}
    */
    readonly regexp: string;
    /**
    * If set to true, will cause the tags list inside the service structure to be stripped of any empty strings.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/prepared_query#remove_empty_tags PreparedQuery#remove_empty_tags}
    */
    readonly removeEmptyTags?: boolean | cdktf.IResolvable;
    /**
    * The type of template matching to perform. Currently only `name_prefix_match` is supported.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/prepared_query#type PreparedQuery#type}
    */
    readonly type: string;
}
export declare function preparedQueryTemplateToTerraform(struct?: PreparedQueryTemplateOutputReference | PreparedQueryTemplate): any;
export declare function preparedQueryTemplateToHclTerraform(struct?: PreparedQueryTemplateOutputReference | PreparedQueryTemplate): any;
export declare class PreparedQueryTemplateOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): PreparedQueryTemplate | undefined;
    set internalValue(value: PreparedQueryTemplate | undefined);
    private _regexp?;
    get regexp(): string;
    set regexp(value: string);
    get regexpInput(): string | undefined;
    private _removeEmptyTags?;
    get removeEmptyTags(): boolean | cdktf.IResolvable;
    set removeEmptyTags(value: boolean | cdktf.IResolvable);
    resetRemoveEmptyTags(): void;
    get removeEmptyTagsInput(): boolean | cdktf.IResolvable | undefined;
    private _type?;
    get type(): string;
    set type(value: string);
    get typeInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/prepared_query consul_prepared_query}
*/
export declare class PreparedQuery extends cdktf.TerraformResource {
    static readonly tfResourceType = "consul_prepared_query";
    /**
    * Generates CDKTF code for importing a PreparedQuery resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the PreparedQuery to import
    * @param importFromId The id of the existing PreparedQuery that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/prepared_query#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the PreparedQuery to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs/resources/prepared_query consul_prepared_query} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options PreparedQueryConfig
    */
    constructor(scope: Construct, id: string, config: PreparedQueryConfig);
    private _connect?;
    get connect(): boolean | cdktf.IResolvable;
    set connect(value: boolean | cdktf.IResolvable);
    resetConnect(): void;
    get connectInput(): boolean | cdktf.IResolvable | undefined;
    private _datacenter?;
    get datacenter(): string;
    set datacenter(value: string);
    resetDatacenter(): void;
    get datacenterInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _ignoreCheckIds?;
    get ignoreCheckIds(): string[];
    set ignoreCheckIds(value: string[]);
    resetIgnoreCheckIds(): void;
    get ignoreCheckIdsInput(): string[] | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _near?;
    get near(): string;
    set near(value: string);
    resetNear(): void;
    get nearInput(): string | undefined;
    private _nodeMeta?;
    get nodeMeta(): {
        [key: string]: string;
    };
    set nodeMeta(value: {
        [key: string]: string;
    });
    resetNodeMeta(): void;
    get nodeMetaInput(): {
        [key: string]: string;
    } | undefined;
    private _onlyPassing?;
    get onlyPassing(): boolean | cdktf.IResolvable;
    set onlyPassing(value: boolean | cdktf.IResolvable);
    resetOnlyPassing(): void;
    get onlyPassingInput(): boolean | cdktf.IResolvable | undefined;
    private _service?;
    get service(): string;
    set service(value: string);
    get serviceInput(): string | undefined;
    private _serviceMeta?;
    get serviceMeta(): {
        [key: string]: string;
    };
    set serviceMeta(value: {
        [key: string]: string;
    });
    resetServiceMeta(): void;
    get serviceMetaInput(): {
        [key: string]: string;
    } | undefined;
    private _session?;
    get session(): string;
    set session(value: string);
    resetSession(): void;
    get sessionInput(): string | undefined;
    private _storedToken?;
    get storedToken(): string;
    set storedToken(value: string);
    resetStoredToken(): void;
    get storedTokenInput(): string | undefined;
    private _tags?;
    get tags(): string[];
    set tags(value: string[]);
    resetTags(): void;
    get tagsInput(): string[] | undefined;
    private _token?;
    get token(): string;
    set token(value: string);
    resetToken(): void;
    get tokenInput(): string | undefined;
    private _dns;
    get dns(): PreparedQueryDnsOutputReference;
    putDns(value: PreparedQueryDns): void;
    resetDns(): void;
    get dnsInput(): PreparedQueryDns | undefined;
    private _failover;
    get failover(): PreparedQueryFailoverOutputReference;
    putFailover(value: PreparedQueryFailover): void;
    resetFailover(): void;
    get failoverInput(): PreparedQueryFailover | undefined;
    private _template;
    get template(): PreparedQueryTemplateOutputReference;
    putTemplate(value: PreparedQueryTemplate): void;
    resetTemplate(): void;
    get templateInput(): PreparedQueryTemplate | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
