/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface ConsulProviderConfig {
    /**
    * The HTTP(S) API address of the agent to use. Defaults to "127.0.0.1:8500".
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs#address ConsulProvider#address}
    */
    readonly address?: string;
    /**
    * A path to a PEM-encoded certificate authority used to verify the remote agent's certificate.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs#ca_file ConsulProvider#ca_file}
    */
    readonly caFile?: string;
    /**
    * A path to a directory of PEM-encoded certificate authority files to use to check the authenticity of client and server connections. Can also be specified with the `CONSUL_CAPATH` environment variable.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs#ca_path ConsulProvider#ca_path}
    */
    readonly caPath?: string;
    /**
    * PEM-encoded certificate authority used to verify the remote agent's certificate.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs#ca_pem ConsulProvider#ca_pem}
    */
    readonly caPem?: string;
    /**
    * A path to a PEM-encoded certificate provided to the remote agent; requires use of `key_file` or `key_pem`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs#cert_file ConsulProvider#cert_file}
    */
    readonly certFile?: string;
    /**
    * PEM-encoded certificate provided to the remote agent; requires use of `key_file` or `key_pem`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs#cert_pem ConsulProvider#cert_pem}
    */
    readonly certPem?: string;
    /**
    * The datacenter to use. Defaults to that of the agent.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs#datacenter ConsulProvider#datacenter}
    */
    readonly datacenter?: string;
    /**
    * HTTP Basic Authentication credentials to be used when communicating with Consul, in the format of either `user` or `user:pass`. This may also be specified using the `CONSUL_HTTP_AUTH` environment variable.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs#http_auth ConsulProvider#http_auth}
    */
    readonly httpAuth?: string;
    /**
    * Boolean value to disable SSL certificate verification; setting this value to true is not recommended for production use. Only use this with scheme set to "https".
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs#insecure_https ConsulProvider#insecure_https}
    */
    readonly insecureHttps?: boolean | cdktf.IResolvable;
    /**
    * A path to a PEM-encoded private key, required if `cert_file` or `cert_pem` is specified.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs#key_file ConsulProvider#key_file}
    */
    readonly keyFile?: string;
    /**
    * PEM-encoded private key, required if `cert_file` or `cert_pem` is specified.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs#key_pem ConsulProvider#key_pem}
    */
    readonly keyPem?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs#namespace ConsulProvider#namespace}
    */
    readonly namespace?: string;
    /**
    * The URL scheme of the agent to use ("http" or "https"). Defaults to "http".
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs#scheme ConsulProvider#scheme}
    */
    readonly scheme?: string;
    /**
    * The ACL token to use by default when making requests to the agent. Can also be specified with `CONSUL_HTTP_TOKEN` or `CONSUL_TOKEN` as an environment variable.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs#token ConsulProvider#token}
    */
    readonly token?: string;
    /**
    * Alias name
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs#alias ConsulProvider#alias}
    */
    readonly alias?: string;
    /**
    * auth_jwt block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs#auth_jwt ConsulProvider#auth_jwt}
    */
    readonly authJwt?: ConsulProviderAuthJwt;
    /**
    * header block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs#header ConsulProvider#header}
    */
    readonly header?: ConsulProviderHeader[] | cdktf.IResolvable;
}
export interface ConsulProviderAuthJwt {
    /**
    * The name of the auth method to use for login.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs#auth_method ConsulProvider#auth_method}
    */
    readonly authMethod: string;
    /**
    * The bearer token to present to the auth method during login for authentication purposes. For the Kubernetes auth method this is a [Service Account Token (JWT)](https://kubernetes.io/docs/reference/access-authn-authz/authentication/#service-account-tokens).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs#bearer_token ConsulProvider#bearer_token}
    */
    readonly bearerToken?: string;
    /**
    * Specifies arbitrary KV metadata linked to the token. Can be useful to track origins.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs#meta ConsulProvider#meta}
    */
    readonly meta?: {
        [key: string]: string;
    };
    /**
    * Whether to use a [Terraform Workload Identity token](https://developer.hashicorp.com/terraform/cloud-docs/workspaces/dynamic-provider-credentials/workload-identity-tokens). The token will be read from the `TFC_WORKLOAD_IDENTITY_TOKEN` environment variable.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs#use_terraform_cloud_workload_identity ConsulProvider#use_terraform_cloud_workload_identity}
    */
    readonly useTerraformCloudWorkloadIdentity?: boolean | cdktf.IResolvable;
}
export declare function consulProviderAuthJwtToTerraform(struct?: ConsulProviderAuthJwt): any;
export declare function consulProviderAuthJwtToHclTerraform(struct?: ConsulProviderAuthJwt): any;
export interface ConsulProviderHeader {
    /**
    * The name of the header.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs#name ConsulProvider#name}
    */
    readonly name: string;
    /**
    * The value of the header.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs#value ConsulProvider#value}
    */
    readonly value: string;
}
export declare function consulProviderHeaderToTerraform(struct?: ConsulProviderHeader | cdktf.IResolvable): any;
export declare function consulProviderHeaderToHclTerraform(struct?: ConsulProviderHeader | cdktf.IResolvable): any;
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs consul}
*/
export declare class ConsulProvider extends cdktf.TerraformProvider {
    static readonly tfResourceType = "consul";
    /**
    * Generates CDKTF code for importing a ConsulProvider resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the ConsulProvider to import
    * @param importFromId The id of the existing ConsulProvider that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the ConsulProvider to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/consul/2.21.0/docs consul} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options ConsulProviderConfig = {}
    */
    constructor(scope: Construct, id: string, config?: ConsulProviderConfig);
    private _address?;
    get address(): string | undefined;
    set address(value: string | undefined);
    resetAddress(): void;
    get addressInput(): string | undefined;
    private _caFile?;
    get caFile(): string | undefined;
    set caFile(value: string | undefined);
    resetCaFile(): void;
    get caFileInput(): string | undefined;
    private _caPath?;
    get caPath(): string | undefined;
    set caPath(value: string | undefined);
    resetCaPath(): void;
    get caPathInput(): string | undefined;
    private _caPem?;
    get caPem(): string | undefined;
    set caPem(value: string | undefined);
    resetCaPem(): void;
    get caPemInput(): string | undefined;
    private _certFile?;
    get certFile(): string | undefined;
    set certFile(value: string | undefined);
    resetCertFile(): void;
    get certFileInput(): string | undefined;
    private _certPem?;
    get certPem(): string | undefined;
    set certPem(value: string | undefined);
    resetCertPem(): void;
    get certPemInput(): string | undefined;
    private _datacenter?;
    get datacenter(): string | undefined;
    set datacenter(value: string | undefined);
    resetDatacenter(): void;
    get datacenterInput(): string | undefined;
    private _httpAuth?;
    get httpAuth(): string | undefined;
    set httpAuth(value: string | undefined);
    resetHttpAuth(): void;
    get httpAuthInput(): string | undefined;
    private _insecureHttps?;
    get insecureHttps(): boolean | cdktf.IResolvable | undefined;
    set insecureHttps(value: boolean | cdktf.IResolvable | undefined);
    resetInsecureHttps(): void;
    get insecureHttpsInput(): boolean | cdktf.IResolvable | undefined;
    private _keyFile?;
    get keyFile(): string | undefined;
    set keyFile(value: string | undefined);
    resetKeyFile(): void;
    get keyFileInput(): string | undefined;
    private _keyPem?;
    get keyPem(): string | undefined;
    set keyPem(value: string | undefined);
    resetKeyPem(): void;
    get keyPemInput(): string | undefined;
    private _namespace?;
    get namespace(): string | undefined;
    set namespace(value: string | undefined);
    resetNamespace(): void;
    get namespaceInput(): string | undefined;
    private _scheme?;
    get scheme(): string | undefined;
    set scheme(value: string | undefined);
    resetScheme(): void;
    get schemeInput(): string | undefined;
    private _token?;
    get token(): string | undefined;
    set token(value: string | undefined);
    resetToken(): void;
    get tokenInput(): string | undefined;
    private _alias?;
    get alias(): string | undefined;
    set alias(value: string | undefined);
    resetAlias(): void;
    get aliasInput(): string | undefined;
    private _authJwt?;
    get authJwt(): ConsulProviderAuthJwt | undefined;
    set authJwt(value: ConsulProviderAuthJwt | undefined);
    resetAuthJwt(): void;
    get authJwtInput(): ConsulProviderAuthJwt | undefined;
    private _header?;
    get header(): ConsulProviderHeader[] | cdktf.IResolvable | undefined;
    set header(value: ConsulProviderHeader[] | cdktf.IResolvable | undefined);
    resetHeader(): void;
    get headerInput(): cdktf.IResolvable | ConsulProviderHeader[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
